@@ -5,17 +5,18 @@ Static configuration for the application.
 TODO: add more (runtime) flexibility in plugin discovery, selection
 and activation.
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function, unicode_literals
 
 import logging
 import os
 import subprocess
 import sys
+from pathlib import Path
 
 import jinja2
 from flask import current_app
 from flask_script import Command, Manager
-from pathlib import Path
+from six import text_type
 from werkzeug.serving import BaseWSGIServer
 
 from abilian.app import Application as BaseApplication
@@ -61,6 +62,7 @@ class Application(BaseApplication):
         "abilian.sbe.apps.wall",
         "abilian.sbe.apps.documents",
         "abilian.sbe.apps.forum",
+        # "abilian.sbe.apps.calendar",
         "abilian.sbe.apps.communities",
         "abilian.sbe.apps.social",
         "abilian.sbe.apps.preferences",)
@@ -78,8 +80,9 @@ class Application(BaseApplication):
         repository.init_app(self)
         converter.init_app(self)
 
+
 # SBE demo app bootstrap stuff
-_SBE_DEMO_SCRIPT = u'''\
+_SBE_DEMO_SCRIPT = '''\
 #!{BIN_DIR}/python
 from __future__ import absolute_import
 
@@ -100,9 +103,9 @@ def _on_http_server_activate(self, *args, **kwargs):
     _BASE_SERVER_ACTIVATE(self, *args, **kwargs)
     # now we are listening to socket
     host, port = self.server_address
-    if host == u'0.0.0.0':
+    if host == '0.0.0.0':
         # chrome is not ok with 0.0.0.0
-        host = u'localhost'
+        host = 'localhost'
     url = 'http://{host}:{port}/setup'.format(host=host, port=port)
 
     if sys.platform == "win32":
@@ -127,29 +130,29 @@ def setup_sbe_app():
         logger.error('Not in a virtualenv! Aborting.')
         return 1
 
-    bin_dir = Path(sys.prefix) / u'bin'
+    bin_dir = Path(sys.prefix) / 'bin'
 
     if not bin_dir.exists() and bin_dir.is_dir():
         logger.error('%s doesn\'t exists or is not a directory. Aborting',
-                     repr(unicode(bin_dir)))
+                     repr(text_type(bin_dir)))
         return 1
 
-    script_file = bin_dir / u'abilian_sbe'
+    script_file = bin_dir / 'abilian_sbe'
     if script_file.exists():
         logger.info('%s already exists. Skipping creation.',
-                    repr(unicode(script_file)))
+                    repr(text_type(script_file)))
     else:
         with script_file.open('w') as out:
-            logger.info('Create script: "%s".', repr(unicode(script_file)))
-            content = _SBE_DEMO_SCRIPT.format(BIN_DIR=unicode(bin_dir))
+            logger.info('Create script: "%s".', repr(text_type(script_file)))
+            content = _SBE_DEMO_SCRIPT.format(BIN_DIR=text_type(bin_dir))
             out.write(content)
-        script_file.chmod(0755)  # 0755: -rwxr-xr-x
+        script_file.chmod(0o755)  # 0755: -rwxr-xr-x
 
     current_app.config['PRODUCTION'] = True
     current_app.config['DEBUG'] = False
     current_app.config['ASSETS_DEBUG'] = False
-    current_app.config['SITE_NAME'] = u'Abilian SBE'
-    current_app.config['MAIL_SENDER'] = u'abilian-sbe-app@example.com'
+    current_app.config['SITE_NAME'] = 'Abilian SBE'
+    current_app.config['MAIL_SENDER'] = 'abilian-sbe-app@example.com'
 
     logger.info('Prepare CSS & JS files')
     command_manager.handle('abilian_sbe', ['assets', 'build'])
