@@ -1,16 +1,16 @@
 # coding=utf-8
 """
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 import imghdr
-from string import strip
 
 import PIL
 import sqlalchemy as sa
 from flask import request
 from flask_babel import gettext as _
 from flask_babel import lazy_gettext as _l
+from six import text_type
 from wtforms.fields import BooleanField, StringField, TextAreaField
 from wtforms.validators import ValidationError, optional, required
 
@@ -23,11 +23,16 @@ from abilian.web.forms.widgets import BooleanWidget, ImageInput, TextArea
 from .models import Community
 
 
+def strip(s):
+    return s.strip()
+
+
 def _group_choices():
     m_prop = Group.members.property
     membership = m_prop.secondary
     query = Group.query.session.query(
-        Group.id, Group.name, Community.name.label('community'),
+        Group.id, Group.name,
+        Community.name.label('community'),
         sa.sql.func.count(membership.c.user_id).label('members_count'))
     query = query.outerjoin(m_prop.secondary, m_prop.primaryjoin) \
         .outerjoin(Community, Community.group.property.primaryjoin) \
@@ -40,16 +45,17 @@ def _group_choices():
         label = u'{} ({:d} membres)'.format(g.name, g.members_count)
         if g.community:
             label += u' — Communauté: {}'.format(g.community)
-        choices.append((unicode(g.id), label))
+        choices.append((text_type(g.id), label))
 
     return choices
 
 
 class CommunityForm(Form):
     name = StringField(label=_l(u"Name"), validators=[required()])
-    description = TextAreaField(label=_l(u"Description"),
-                                validators=[required(), length(max=500)],
-                                widget=TextArea(resizeable="vertical"))
+    description = TextAreaField(
+        label=_l(u"Description"),
+        validators=[required(), length(max=500)],
+        widget=TextArea(resizeable="vertical"))
 
     linked_group = Select2Field(
         label=_l(u'Linked to group'),
@@ -57,21 +63,23 @@ class CommunityForm(Form):
             u'Manages a group of users through this community members.'),
         choices=_group_choices)
 
-    image = FileField(label=_l('Image'),
-                      widget=ImageInput(width=65, height=65),
-                      validators=[optional()])
+    image = FileField(
+        label=_l('Image'),
+        widget=ImageInput(
+            width=65, height=65),
+        validators=[optional()])
 
     type = Select2Field(label=_(u"Type"), validators=[required()],
                         filters=(strip,),
                         choices=[(_l(u'informative'), 'informative'),
                                  (_l(u'participative'), 'participative')])
 
-    has_documents = BooleanField(label=_l(u"Has documents"),
-                                 widget=BooleanWidget(on_off_mode=True))
-    has_wiki = BooleanField(label=_l(u"Has a wiki"),
-                            widget=BooleanWidget(on_off_mode=True))
-    has_forum = BooleanField(label=_l(u"Has a forum"),
-                             widget=BooleanWidget(on_off_mode=True))
+    has_documents = BooleanField(
+        label=_l(u"Has documents"), widget=BooleanWidget(on_off_mode=True))
+    has_wiki = BooleanField(
+        label=_l(u"Has a wiki"), widget=BooleanWidget(on_off_mode=True))
+    has_forum = BooleanField(
+        label=_l(u"Has a forum"), widget=BooleanWidget(on_off_mode=True))
 
     def validate_name(self, field):
         name = field.data = field.data.strip()
