@@ -1,7 +1,7 @@
 # coding=utf-8
 """
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 import logging
 import time
@@ -11,8 +11,9 @@ from os.path import dirname, join
 import sqlalchemy as sa
 from blinker import ANY
 from flask import current_app
-from sqlalchemy import (Boolean, Column, DateTime, ForeignKey, Integer, String,
-                        Unicode, UniqueConstraint, and_)
+from sqlalchemy import Boolean, Column, DateTime, ForeignKey, Integer, \
+    String, Unicode, UniqueConstraint, and_
+from sqlalchemy.event import listens_for
 from sqlalchemy.orm import backref, relation, relationship
 from sqlalchemy.orm.attributes import OP_APPEND, OP_REMOVE
 
@@ -35,24 +36,25 @@ from . import signals
 logger = logging.getLogger(__name__)
 
 MEMBER = Role('member', label=_l(u'role_member'), assignable=False)
-VALID_ROLES = frozenset((READER, WRITER, MANAGER, MEMBER,))
+VALID_ROLES = frozenset([READER, WRITER, MANAGER, MEMBER])
 
 
 class Membership(db.Model):
-    """Represents the membership of someone in a community."""
+    """Represents the membership of someone in a community.
+    """
     __tablename__ = 'community_membership'
 
     id = Column(Integer, primary_key=True)
 
     user_id = Column(ForeignKey('user.id'), index=True, nullable=False)
-    user = relationship(User,
-                        lazy='joined',
-                        backref=backref('communautes_membership',
-                                        lazy='select'))
+    user = relationship(
+        User,
+        lazy='joined',
+        backref=backref(
+            'communautes_membership', lazy='select'))
 
     community_id = Column(
-        ForeignKey('community.id'),
-        index=True, nullable=False)
+        ForeignKey('community.id'), index=True, nullable=False)
     community = relationship('Community', lazy='joined')
 
     role = Column(RoleType())  # should be either 'member' or 'manager'
@@ -66,9 +68,9 @@ class Membership(db.Model):
 
 
 def community_content(cls):
-    """
-    Class decorator to mark models considered as community content. This is
-    required for proper indexation.
+    """Class decorator to mark models considered as community content.
+
+    This is required for proper indexation.
     """
     cls.is_community_content = True
 
@@ -77,7 +79,7 @@ def community_content(cls):
 
     cls.community_slug = property(community_slug)
     index_to = cls.__indexation_args__.setdefault('index_to', ())
-    index_to += (('community_slug', ('community_slug',),),)
+    index_to += (('community_slug', ('community_slug',)),)
     cls.__indexation_args__['index_to'] = index_to
 
     def _indexable_roles_and_users(self):
@@ -90,8 +92,7 @@ def community_content(cls):
 
 
 def indexable_roles_and_users(community):
-    """
-    Mixin to use to replace Entity._indexable_roles_and_users.
+    """Mixin to use to replace Entity._indexable_roles_and_users.
 
     Will be removed when communities are upgraded to use standard role based
     access (by setting permissions and using security service).
@@ -100,7 +101,8 @@ def indexable_roles_and_users(community):
 
 
 class Community(Entity):
-    """Ad-hoc objects that hold properties about a community."""
+    """Ad-hoc objects that hold properties about a community.
+    """
     __indexation_args__ = {}
     __indexation_args__.update(Entity.__indexation_args__)
     index_to = __indexation_args__.setdefault('index_to', ())
@@ -112,25 +114,25 @@ class Community(Entity):
 
     # : A public description.
     description = Column(
-        Unicode(500), default=u"",
-        nullable=False,
-        info=SEARCHABLE)
+        Unicode(500), default=u"", nullable=False, info=SEARCHABLE)
 
     #: An image or logo for this community.
     image_id = Column(ForeignKey(Blob.id), index=True)
     image = relationship(Blob, lazy='joined')
 
     #: The root folder for this community.
-    folder_id = Column(Integer,
-                       ForeignKey(Folder.id,
-                                  use_alter=True,
-                                  name='fk_community_root_folder'),
-                       unique=True)
-    folder = relation(Folder,
-                      single_parent=True,  # required for delete-orphan
-                      primaryjoin=(folder_id == Folder.id),
-                      cascade='all, delete-orphan',
-                      backref=backref('_community', lazy='select', uselist=False))
+    folder_id = Column(
+        Integer,
+        ForeignKey(
+            Folder.id, use_alter=True, name='fk_community_root_folder'),
+        unique=True)
+    folder = relation(
+        Folder,
+        single_parent=True,  # required for delete-orphan
+        primaryjoin=(folder_id == Folder.id),
+        cascade='all, delete-orphan',
+        backref=backref(
+            '_community', lazy='select', uselist=False))
 
     #: The group this community is linked to, if any. Memberships are then
     #: reflected
@@ -141,28 +143,24 @@ class Community(Entity):
     memberships = relationship(Membership, cascade="all, delete-orphan")
 
     #: direct access to :class:`User` members
-    members = relationship(User,
-                           secondary=Membership.__table__,
-                           viewonly=True,
-                           backref=backref('communities',
-                                           lazy='select',
-                                           viewonly=True),)
+    members = relationship(
+        User,
+        secondary=Membership.__table__,
+        viewonly=True,
+        backref=backref(
+            'communities', lazy='select', viewonly=True))
 
     #: Number of members in this community.
     membership_count = Column(
-        Integer, default=0,
-        nullable=False, info=NOT_AUDITABLE)
+        Integer, default=0, nullable=False, info=NOT_AUDITABLE)
 
     #: Number of documents in this community.
     document_count = Column(
-        Integer, default=0,
-        nullable=False, info=NOT_AUDITABLE)
+        Integer, default=0, nullable=False, info=NOT_AUDITABLE)
 
     #: Last time something happened in this community
-    last_active_at = Column(DateTime,
-                            default=datetime.utcnow,
-                            nullable=False,
-                            info=NOT_AUDITABLE)
+    last_active_at = Column(
+        DateTime, default=datetime.utcnow, nullable=False, info=NOT_AUDITABLE)
 
     # Various features for this community:
 
@@ -201,20 +199,25 @@ class Community(Entity):
                 # during creation, we may have to provide a temporary name for
                 # subfolder, we don't want empty names on folders since they must be
                 # unique among siblings
-                name = u'{}_{}-{}'.format(self.__class__.__name__, str(self.id),
-                                          time.asctime())
+                name = u'{}_{}-{}'.format(self.__class__.__name__,
+                                          str(self.id), time.asctime())
             self.folder = repository.root_folder.create_subfolder(name)
             #if not self.group:
             #  self.group = Group(name=self.name)
 
         if not self.image:
             fn = join(dirname(__file__), "data", "community.png")
-            self.image = Blob(open(fn).read())
+            self.image = Blob(open(fn, 'rb').read())
+
+    @property
+    def has_calendar(self):
+        config = current_app.config
+        return bool(config.get("ENABLE_CALENDAR"))
 
     def rename(self, name):
         self.name = name
         if self.folder:
-            #FIXME: use signals
+            # FIXME: use signals
             self.folder.name = name
 
     def get_memberships(self, role=None):
@@ -256,7 +259,8 @@ class Community(Entity):
     def remove_membership(self, user):
         M = Membership
         membership = M.query \
-          .filter(and_(M.user_id == user.id, M.community_id == self.id)).first()
+            .filter(and_(M.user_id == user.id, M.community_id == self.id)) \
+            .first()
         if not membership:
             raise KeyError("User {} is not a member of community {}".format(
                 user, self))
@@ -286,7 +290,8 @@ class Community(Entity):
                 security.ungrant_role(principal, role, self.folder)
 
     def get_role(self, user):
-        """Returns the given user's role in this community."""
+        """Returns the given user's role in this community.
+        """
         M = Membership
         membership = current_app.db.session() \
             .query(M.role) \
@@ -323,6 +328,7 @@ def CommunityIdColumn():
         nullable=False,
         info=SEARCHABLE | dict(index_to=(('community_id', ('community_id',)),)))
 
+
 # Handlers to keep community/group members in sync
 #
 _PROCESSED_ATTR = '__sbe_community_group_sync_processed__'
@@ -355,8 +361,8 @@ def membership_removed(sender, membership):
         sender.group.members.discard(membership.user)
 
 
-@sa.event.listens_for(Community.members, 'append')
-@sa.event.listens_for(Community.members, 'remove')
+@listens_for(Community.members, 'append')
+@listens_for(Community.members, 'remove')
 def _on_member_change(community, user, initiator):
     group = community.group
     if not group:
@@ -379,7 +385,7 @@ def _on_member_change(community, user, initiator):
             group.members.discard(user)
 
 
-@sa.event.listens_for(Community.group, 'set', active_history=True)
+@listens_for(Community.group, 'set', active_history=True)
 def _on_linked_group_change(community, value, oldvalue, initiator):
     if value == oldvalue:
         return
@@ -415,8 +421,8 @@ def _safe_get_community(group):
             return None
 
 
-@sa.event.listens_for(Group.members, 'append')
-@sa.event.listens_for(Group.members, 'remove')
+@listens_for(Group.members, 'append')
+@listens_for(Group.members, 'remove')
 def _on_group_member_change(group, user, initiator):
     community = _safe_get_community(group)
 
@@ -443,7 +449,7 @@ def _on_group_member_change(group, user, initiator):
         community.remove_membership(user)
 
 
-@sa.event.listens_for(Group.members, 'set', active_history=True)
+@listens_for(Group.members, 'set', active_history=True)
 def _on_group_members_replace(group, value, oldvalue, initiator):
     if value == oldvalue:
         return
