@@ -1,7 +1,7 @@
 # coding=utf-8
 """
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 import logging
 
@@ -18,9 +18,7 @@ _COMMUNITY_CONTENT_FIELDNAME = 'is_community_content'
 _COMMUNITY_CONTENT_FIELD = wf.BOOLEAN()
 
 _COMMUNITY_ID_FIELD = wf.NUMERIC(
-    numtype=int, bits=64,
-    signed=False, stored=True,
-    unique=False)
+    numtype=int, bits=64, signed=False, stored=True, unique=False)
 _COMMUNITY_SLUG_FIELD = wf.ID(stored=True)
 
 _FIELDS = [
@@ -56,7 +54,7 @@ def filter_user_communities():
 
     filter_q = wq.Term(_COMMUNITY_CONTENT_FIELDNAME, False)
 
-    if not current_user.is_anonymous():
+    if not current_user.is_anonymous:
         ids = Membership.query \
             .filter(Membership.user == current_user) \
             .order_by(Membership.community_id.asc()) \
@@ -64,8 +62,9 @@ def filter_user_communities():
         communities = [wq.Term('community_id', i[0]) for i in ids]
 
         if communities:
-            communities = wq.And([wq.Term(_COMMUNITY_CONTENT_FIELDNAME, True),
-                                  wq.Or(communities)])
+            communities = wq.And([
+                wq.Term(_COMMUNITY_CONTENT_FIELDNAME, True), wq.Or(communities)
+            ])
             filter_q = wq.Or([filter_q, communities])
 
     return filter_q
