@@ -2,6 +2,8 @@
 Decorators and helpers to check access to communities.
 """
 
+from __future__ import absolute_import, print_function
+
 from functools import wraps
 
 from flask import current_app, g
@@ -56,7 +58,7 @@ def check_access(community=None, user=None):
 def has_access(community=None, user=None):
     if not user:
         user = current_user
-    if user.is_anonymous():
+    if user.is_anonymous:
         return False
 
     security = current_app.services['security']
