@@ -1,24 +1,25 @@
 # coding=utf-8
 """
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
-import cStringIO as StringIO
 import hashlib
 import logging
 from datetime import datetime
 from functools import wraps
+from io import BytesIO
 from operator import attrgetter
+from pathlib import Path
 from time import gmtime, strftime
 
 import openpyxl
 import pytz
 import sqlalchemy as sa
-from flask import (current_app, flash, g, jsonify, redirect, render_template,
-                   request, session, url_for)
+from flask import current_app, flash, g, jsonify, redirect, render_template, \
+    request, session, url_for
 from flask_login import current_user, login_required
 from openpyxl.writer.write_only import WriteOnlyCell
-from pathlib import Path
+from six import text_type
 from werkzeug.exceptions import BadRequest, InternalServerError, NotFound
 from whoosh.searching import Hit
 
@@ -54,10 +55,11 @@ def seconds_since_epoch(dt):
     return int((utc_dt(dt) - EPOCH).total_seconds())
 
 
-communities = Blueprint("communities",
-                        __name__,
-                        set_community_id_prefix=False,
-                        template_folder='templates')
+communities = Blueprint(
+    "communities",
+    __name__,
+    set_community_id_prefix=False,
+    template_folder='templates')
 route = communities.route
 add_url = communities.add_url_rule
 communities.record_once(register_actions)
@@ -95,10 +97,10 @@ def default_view_kw(kw, obj, obj_type, obj_id, **kwargs):
     Helper for using :func:`abilian.web.views.default_view` on objects that
     belongs to a community. This function should be used as `kw_func`::
 
-      @default_view(blueprint, Model, kw_func=default_view_kw)
-      @blueprint.route("/<object_id>")
-      def view():
-         ...
+        @default_view(blueprint, Model, kw_func=default_view_kw)
+        @blueprint.route("/<object_id>")
+        def view():
+            ...
 
     """
     is_community = obj_type == Community.entity_type
@@ -109,8 +111,8 @@ def default_view_kw(kw, obj, obj_type, obj_id, **kwargs):
         # override with the slug value.
         if obj:
             if isinstance(obj, (Hit, dict)):
-                community_id = obj.get('slug' if is_community else
-                                       'community_slug')
+                community_id = obj.get('slug'
+                                       if is_community else 'community_slug')
             elif is_community:
                 community_id = obj.slug
             elif community_id is None and hasattr(obj, 'community'):
@@ -154,10 +156,8 @@ def index():
 
 
 @route("/<string:community_id>/")
-@views.default_view(communities,
-                    Community,
-                    'community_id',
-                    kw_func=default_view_kw)
+@views.default_view(
+    communities, Community, 'community_id', kw_func=default_view_kw)
 def community():
     return redirect(url_for("wall.index", community_id=g.community.slug))
 
@@ -214,7 +214,7 @@ class BaseCommunityView(object):
 class CommunityEdit(BaseCommunityView, views.ObjectEdit):
     template = 'community/edit.html'
     title = _l("Edit community")
-    decorators = views.ObjectEdit.decorators + (require_admin, tab('settings'),)
+    decorators = views.ObjectEdit.decorators + (require_admin, tab('settings'))
 
     def breadcrumb(self):
         return BreadcrumbItem(label=_(u'Settings'),
@@ -245,11 +245,12 @@ class CommunityEdit(BaseCommunityView, views.ObjectEdit):
         self.obj.group = self.linked_group
 
 
-add_url("/<string:community_id>/settings",
-        view_func=CommunityEdit.as_view(
-            'settings',
-            view_endpoint='.community',
-            message_success=_l(u"Community settings saved successfully.")))
+add_url(
+    "/<string:community_id>/settings",
+    view_func=CommunityEdit.as_view(
+        'settings',
+        view_endpoint='.community',
+        message_success=_l(u"Community settings saved successfully.")))
 
 
 class CommunityCreate(views.ObjectCreate, CommunityEdit):
@@ -267,25 +268,25 @@ class CommunityCreate(views.ObjectCreate, CommunityEdit):
 
 add_url(
     '/new',
-    view_func=CommunityCreate.as_view('new', view_endpoint='.community'))
+    view_func=CommunityCreate.as_view(
+        'new', view_endpoint='.community'))
 
 
 class CommunityDelete(BaseCommunityView, views.ObjectDelete):
     get_form_kwargs = views.ObjectDelete.get_form_kwargs
 
 
-add_url("/<string:community_id>/destroy",
-        methods=['POST'],
-        view_func=CommunityDelete.as_view(
-            'delete', message_success=_l(u"Community destroyed.")))
+add_url(
+    "/<string:community_id>/destroy",
+    methods=['POST'],
+    view_func=CommunityDelete.as_view(
+        'delete', message_success=_l(u"Community destroyed.")))
 
 # Community Image
 _DEFAULT_IMAGE = Path(__file__).parent / u'data' / u'community.png'
 _DEFAULT_IMAGE_MD5 = hashlib.md5(_DEFAULT_IMAGE.open('rb').read()).hexdigest()
-route('/_default_image')(
-    image_views.StaticImageView.as_view('community_default_image',
-                                        set_expire=True,
-                                        image=_DEFAULT_IMAGE,))
+route('/_default_image')(image_views.StaticImageView.as_view(
+    'community_default_image', set_expire=True, image=_DEFAULT_IMAGE))
 
 
 class CommunityImageView(image_views.BlobView):
@@ -345,10 +346,11 @@ def members():
     )
     memberships = _members_query().all()
 
-    return render_template("community/members.html",
-                           seconds_since_epoch=seconds_since_epoch,
-                           memberships=memberships,
-                           csrf_token=csrf.field())
+    return render_template(
+        "community/members.html",
+        seconds_since_epoch=seconds_since_epoch,
+        memberships=memberships,
+        csrf_token=csrf.field())
 
 
 @route("/<string:community_id>/members", methods=["POST"])
@@ -365,7 +367,7 @@ def members_post():
     user_id = int(user_id)
     user = User.query.get(user_id)
 
-    if action in ('add-user-role', 'set-user-role',):
+    if action in ('add-user-role', 'set-user-role'):
         role = request.form.get("role").lower()
 
         community.set_membership(user, role)
@@ -402,12 +404,11 @@ MEMBERS_EXPORT_HEADERS = [
     _l(u'Role'),
 ]
 
-MEMBERS_EXPORT_ATTRS = ['User', 'User.email', 'last_activity_date', 'role',]
+MEMBERS_EXPORT_ATTRS = ['User', 'User.email', 'last_activity_date', 'role']
 
 HEADER_FONT = openpyxl.styles.Font(bold=True)
-HEADER_ALIGN = openpyxl.styles.Alignment(horizontal='center',
-                                         vertical='top',
-                                         wrapText=True)
+HEADER_ALIGN = openpyxl.styles.Alignment(
+    horizontal='center', vertical='top', wrapText=True)
 XLSX_MIME = u'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
 
 
@@ -433,7 +434,7 @@ def members_excel_export():
 
     cols_width = []
     for col, label in enumerate(MEMBERS_EXPORT_HEADERS, 1):
-        value = unicode(label)
+        value = text_type(label)
         cell = WriteOnlyCell(ws, value=value)
         cell.font = HEADER_FONT
         cell.alignment = HEADER_ALIGN
@@ -453,13 +454,13 @@ def members_excel_export():
                 pass
 
             if isinstance(value, (BaseModel, Role)):
-                value = unicode(value)
+                value = text_type(value)
 
             cell = WriteOnlyCell(ws, value=value)
             cells.append(value)
 
             # estimate width
-            value = unicode(cell.value)
+            value = text_type(cell.value)
             width = max(len(l) for l in value.split(u'\n')) + 1
             cols_width[col] = max(width, cols_width[col])
 
@@ -474,11 +475,11 @@ def members_excel_export():
         width = min(max(width, MIN_WIDTH), MAX_WIDTH)
         ws.column_dimensions[letter].width = width
 
-    fd = StringIO.StringIO()
+    fd = BytesIO()
     wb.save(fd)
     fd.seek(0)
 
-    response = current_app.response_class(fd, mimetype=XLSX_MIME,)
+    response = current_app.response_class(fd, mimetype=XLSX_MIME)
 
     filename = u'{}-members-{}.xlsx'.format(
         community.slug, strftime("%d:%m:%Y-%H:%M:%S", gmtime()))
@@ -505,7 +506,10 @@ def doc(doc_id):
             break
         folder = parent
     target_community = Community.query \
-        .filter(Community.folder_id == folder.id).one()
-    return redirect(url_for("documents.document_view",
-                            community_id=target_community.slug,
-                            doc_id=doc.id))
+        .filter(Community.folder_id == folder.id) \
+        .one()
+    location = url_for(
+        "documents.document_view",
+        community_id=target_community.slug,
+        doc_id=doc.id)
+    return redirect(location)
