@@ -9,13 +9,14 @@ from abilian.sbe.extension import sbe
 
 def register_plugin(app):
     sbe.init_app(app)
-    from .views import documents
+
+    from .views import blueprint
     from .models import setup_listener
     from .commands import manager
     from . import signals  # noqa
     from . import lock
 
-    app.register_blueprint(documents)
+    app.register_blueprint(blueprint)
     setup_listener()
 
     # set default lock lifetime
