@@ -1,7 +1,7 @@
 # coding=utf-8
 """
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 import sqlalchemy as sa
 from flask_script import Manager
@@ -9,13 +9,14 @@ from flask_script import Manager
 from . import tasks
 from .models import Document
 
-manager = Manager(description='SBE documents actions',
-                  help='SBE documents actions')
+manager = Manager(
+    description='SBE documents actions', help='SBE documents actions')
 
 
 @manager.command
 def antivirus():
-    """Schedule documents to antivirus scan."""
+    """Schedule documents to antivirus scan.
+    """
 
     documents = Document.query \
         .filter(Document.content_blob != None) \
@@ -32,5 +33,5 @@ def antivirus():
             tasks.antivirus_scan.delay(d.id)
             count += 1
 
-    print('{count}/{total} documents scheduled'.format(count=count,
-                                                       total=total))
+    print('{count}/{total} documents scheduled'.format(
+        count=count, total=total))
