@@ -4,7 +4,7 @@ Entity objects for the Document Management applications.
 
 TODO: move to an independent service / app.
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 import hashlib
 import itertools
@@ -19,7 +19,8 @@ import sqlalchemy as sa
 import whoosh.fields as wf
 from flask import current_app, g, json, url_for
 from flask_login import current_user
-from sqlalchemy import event
+from six import text_type
+from sqlalchemy.event import listen, listens_for
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.orm import backref, foreign, relationship, remote
 from sqlalchemy.orm.session import Session
@@ -34,8 +35,8 @@ from abilian.core.models.blob import Blob
 from abilian.core.models.subjects import Group, User
 from abilian.services.conversion import converter
 from abilian.services.indexing import indexable_role
-from abilian.services.security import (Admin, Anonymous, InheritSecurity,
-                                       security)
+from abilian.services.security import Admin, Anonymous, InheritSecurity, \
+    security
 
 from . import tasks
 from .lock import Lock
@@ -65,7 +66,8 @@ def icon_exists(filename):
 # Domain classes
 #
 class CmisObject(Entity, InheritSecurity):
-    """(Abstract) Base class for CMIS objects."""
+    """(Abstract) Base class for CMIS objects.
+    """
 
     # normally set by communities.models.community_content,
     # but we have to fix a circ.dep to use it
@@ -76,8 +78,9 @@ class CmisObject(Entity, InheritSecurity):
     __indexation_args__ = {}
     __indexation_args__.update(Entity.__indexation_args__)
     index_to = Entity.__indexation_args__.setdefault('index_to', ())
-    index_to += (('community.id', ('community_id',)),
-                 ('community.slug', ('community_slug',)),)
+    index_to += (
+        ('community.id', ('community_id',)),
+        ('community.slug', ('community_slug',)),)
     __indexation_args__['index_to'] = index_to
     del index_to
 
@@ -131,9 +134,10 @@ class CmisObject(Entity, InheritSecurity):
         new_obj = self.__class__(title=title, name=title, parent=parent)
         state = vars(self)
         for k, v in state.items():
-            if not k.startswith("_") and k not in ['uid', 'id', 'parent',
-                                                   'title', 'name', 'path',
-                                                   'subfolders', 'documents']:
+            if not k.startswith("_") and k not in [
+                    'uid', 'id', 'parent', 'title', 'name', 'path',
+                    'subfolders', 'documents'
+            ]:
                 setattr(new_obj, k, v)
         if self.parent:
             assert self in self.parent.children
@@ -169,10 +173,10 @@ class CmisObject(Entity, InheritSecurity):
         return self.parent and self.parent.community
 
 
-@event.listens_for(CmisObject.name, "set", propagate=True, active_history=True)
+@listens_for(CmisObject.name, "set", propagate=True, active_history=True)
 def _cmis_sync_name_title(entity, new_value, old_value, initiator):
-    """
-    Synchronize CmisObject name -> title.
+    """Synchronize CmisObject name -> title.
+
     CmisObject.title -> name is done via hybrid_property, avoiding infinite
     loop (since "set" is received before attribute has received value)
     """
@@ -183,11 +187,12 @@ def _cmis_sync_name_title(entity, new_value, old_value, initiator):
 
 class PathAndSecurityIndexable(object):
     """
-    Mixin for folder and documents indexation
+    Mixin for folder and documents indexation.
     """
-    __indexation_args__ = dict(index_to=(
-        ('_indexable_parent_ids', ('parent_ids',)),
-        ('_indexable_roles_and_users', ('allowed_roles_and_users',)),),)
+    __indexation_args__ = dict(
+        index_to=(
+            ('_indexable_parent_ids', ('parent_ids',)),
+            ('_indexable_roles_and_users', ('allowed_roles_and_users',)),),)
 
     def _iter_to_root(self, skip_self=False):
         obj = self if not skip_self else self.parent
@@ -198,16 +203,16 @@ class PathAndSecurityIndexable(object):
     @property
     def _indexable_parent_ids(self):
         """
-        returns a string made of ids separated by a slash: "/1/3/4/5", "5" being
+        Return a string made of ids separated by a slash: "/1/3/4/5", "5" being
         self.parent.id.
         """
-        ids = [unicode(obj.id) for obj in self._iter_to_root(skip_self=True)]
+        ids = [text_type(obj.id) for obj in self._iter_to_root(skip_self=True)]
         return u'/' + u'/'.join(reversed(ids))
 
     @property
     def _indexable_roles_and_users(self):
         """
-        returns a string made of type:id elements, like "user:2 group:1 user:6"
+        Returns a string made of type:id elements, like "user:2 group:1 user:6"
         """
         iter_from_root = reversed(list(self._iter_to_root()))
         if self.parent:
@@ -230,8 +235,9 @@ class PathAndSecurityIndexable(object):
             remaining = parent_allowed - obj_allowed
             # find users who can access 'obj' because of their group memberships
             # 1. extends groups in obj_allowed with their actual member list
-            extended_allowed = set(itertools.chain(*(p.members if isinstance(
-                p, Group) else (p,) for p in obj_allowed)))
+            extended_allowed = set(
+                itertools.chain(*(p.members if isinstance(p, Group) else (p,)
+                                  for p in obj_allowed)))
 
             # 2. remaining_users are users explicitly listed in parents but not on
             # obj. Are they in a group?
@@ -239,8 +245,9 @@ class PathAndSecurityIndexable(object):
             allowed |= (remaining_users & extended_allowed)
 
             # remaining groups: find if some users are eligible
-            remaining_groups_members = set(itertools.chain(*(
-                p.members for p in remaining if isinstance(p, Group))))
+            remaining_groups_members = set(
+                itertools.chain(*(p.members for p in remaining
+                                  if isinstance(p, Group))))
             allowed |= remaining_groups_members - extended_allowed
 
         # admin role is always granted access
@@ -249,30 +256,31 @@ class PathAndSecurityIndexable(object):
 
 
 class Folder(CmisObject, PathAndSecurityIndexable):
-    __tablename__ = None
+    __tablename__ = None  # type: str
     sbe_type = 'cmis:folder'
 
     __indexable__ = True
     __indexation_args__ = {}
     __indexation_args__.update(CmisObject.__indexation_args__)
-    index_to = tuple()
+    index_to = ()
     index_to += CmisObject.__indexation_args__.setdefault('index_to', ())
     index_to += PathAndSecurityIndexable.__indexation_args__.setdefault(
         'index_to', ())
     __indexation_args__['index_to'] = index_to
     del index_to
 
-    _indexable_roles_and_users = PathAndSecurityIndexable.\
-                                 _indexable_roles_and_users
+    _indexable_roles_and_users = PathAndSecurityIndexable. \
+        _indexable_roles_and_users
 
     parent = relationship(
         "Folder",
-        primaryjoin=(lambda: foreign(CmisObject._parent_id) == remote(Folder.id)
-                    ),
-        backref=backref('subfolders',
-                        lazy="joined",
-                        order_by='Folder.title',
-                        cascade='all, delete-orphan'))
+        primaryjoin=(
+            lambda: foreign(CmisObject._parent_id) == remote(Folder.id)),
+        backref=backref(
+            'subfolders',
+            lazy="joined",
+            order_by='Folder.title',
+            cascade='all, delete-orphan'))
 
     @property
     def icon(self):
@@ -334,14 +342,12 @@ class Folder(CmisObject, PathAndSecurityIndexable):
     @property
     def filtered_children(self):
         return security.filter_with_permission(
-            g.user, "read", self.children,
-            inherit=True)
+            g.user, "read", self.children, inherit=True)
 
     @property
     def filtered_subfolders(self):
         return security.filter_with_permission(
-            g.user, "read", self.subfolders,
-            inherit=True)
+            g.user, "read", self.subfolders, inherit=True)
 
     def get_local_roles_assignments(self):
         local_roles_assignments = security.get_role_assignements(self)
@@ -355,8 +361,8 @@ class Folder(CmisObject, PathAndSecurityIndexable):
             return []
 
         roles = self.parent.get_local_roles_assignments()
-        inherited_roles = (self.parent.get_inherited_roles_assignments() if
-                           self.parent.inherit_security else [])
+        inherited_roles = (self.parent.get_inherited_roles_assignments()
+                           if self.parent.inherit_security else [])
 
         assignments = set(itertools.chain(roles, inherited_roles))
 
@@ -376,8 +382,8 @@ class Folder(CmisObject, PathAndSecurityIndexable):
 
     def members(self):
         local_roles = self.get_local_roles_assignments()
-        inherited_roles = (self.get_inherited_roles_assignments() if
-                           self.inherit_security else [])
+        inherited_roles = (self.get_inherited_roles_assignments()
+                           if self.inherit_security else [])
 
         def _iter_users(roles):
             for principal, user in roles:
@@ -388,21 +394,20 @@ class Folder(CmisObject, PathAndSecurityIndexable):
                                                 principal.admins):
                         yield user
 
-        members = set(_iter_users(itertools.chain(local_roles,
-                                                  inherited_roles)))
+        members = set(
+            _iter_users(itertools.chain(local_roles, inherited_roles)))
         members = sorted(members, key=lambda u: (u.last_name, u.first_name))
         return members
 
 
 class BaseContent(CmisObject):
-    """ A base class for cmisobject with an attached file
+    """A base class for cmisobject with an attached file.
     """
-    __tablename__ = None
+    __tablename__ = None  # type: str  # type: str
 
     _content_id = Column(Integer, db.ForeignKey(Blob.id))
-    content_blob = relationship(Blob,
-                                cascade='all, delete',
-                                foreign_keys=[_content_id])
+    content_blob = relationship(
+        Blob, cascade='all, delete', foreign_keys=[_content_id])
 
     #: md5 digest (BTW: not sure they should be part of the public API).
     content_digest = Column(Text)
@@ -413,16 +418,17 @@ class BaseContent(CmisObject):
         default=0,
         nullable=False,
         server_default=sa.text('0'),
-        info=dict(searchable=True,
-                  index_to=(('content_length', wf.NUMERIC(stored=True)),),))
+        info=dict(
+            searchable=True,
+            index_to=(('content_length', wf.NUMERIC(stored=True)),)))
 
     #: MIME type of the content stream.
     # TODO: normalize mime type?
     content_type = Column(
         Text,
         default="application/octet-stream",
-        info=dict(searchable=True,
-                  index_to=(('content_type', wf.ID(stored=True)),)),)
+        info=dict(
+            searchable=True, index_to=(('content_type', wf.ID(stored=True)),)))
 
     @property
     def content(self):
@@ -430,7 +436,7 @@ class BaseContent(CmisObject):
 
     @content.setter
     def content(self, value):
-        assert isinstance(value, str)
+        assert isinstance(value, bytes)
         self.content_blob = Blob()
         self.content_blob.value = value
         self.content_length = len(value)
@@ -447,19 +453,19 @@ class BaseContent(CmisObject):
             self.content_type = content_type
 
     def find_content_type(self, content_type=None):
-        """ Find possibly more appropriate content_type for this instance.
+        """Find possibly more appropriate content_type for this instance.
 
         If `content_type` is a binary one, try to find a better one based on
         content name so that 'xxx.pdf' is not flagged as binary/octet-stream for
         example
         """
-        if not content_type or content_type in ('application/octet-stream',
-                                                'binary/octet-stream',
-                                                'application/binary'):
+        if not content_type or content_type in (
+                'application/octet-stream', 'binary/octet-stream',
+                'application/binary', 'multipart/octet-stream'):
             # absent or generic content type: try to find something more useful to be
             # able to do preview/indexing/...
-            guessed_content_type = mimetypes.guess_type(self.title,
-                                                        strict=False)[0]
+            guessed_content_type = mimetypes.guess_type(
+                self.title, strict=False)[0]
             if (guessed_content_type and guessed_content_type !=
                     'application/vnd.ms-office.activeX'):
                 # mimetypes got an update: "random.bin" would be guessed as
@@ -471,27 +477,13 @@ class BaseContent(CmisObject):
 
     @property
     def icon(self):
-        icon = icon_for(self.content_type)
-
-        if not icon.endswith("/bin.png"):
-            return icon
-
-        # Try harder, just in case. XXX: Could be probably removed later when we are
-        # sure that all our bases are covered.
-        if "." not in self.title:
-            return icon_url('bin.png')
-
-        suffix = self.title.split(".")[-1]
-        icon = u'{}.png'.format(suffix)
-        if icon_exists(icon):
-            return icon_url(icon)
-        else:
-            return icon_url('bin.png')
+        return icon_for(self.content_type)
 
 
 class Document(BaseContent, PathAndSecurityIndexable):
-    """A document, in the CMIS sense."""
-    __tablename__ = None
+    """A document, in the CMIS sense.
+    """
+    __tablename__ = None  # type: str
 
     __indexable__ = True
     __indexation_args__ = {}
@@ -510,10 +502,11 @@ class Document(BaseContent, PathAndSecurityIndexable):
     parent = relationship(
         "Folder",
         primaryjoin=(foreign(CmisObject._parent_id) == remote(Folder.id)),
-        backref=backref('documents',
-                        lazy="joined",
-                        order_by='Document.title',
-                        cascade='all, delete-orphan'))
+        backref=backref(
+            'documents',
+            lazy="joined",
+            order_by='Document.title',
+            cascade='all, delete-orphan'))
 
     PREVIEW_SIZE = 700
 
@@ -534,21 +527,20 @@ class Document(BaseContent, PathAndSecurityIndexable):
         return self.content_digest
 
     _text_id = Column(Integer, db.ForeignKey(Blob.id), info=NOT_AUDITABLE)
-    text_blob = relationship(Blob,
-                             cascade='all, delete',
-                             foreign_keys=[_text_id])
+    text_blob = relationship(
+        Blob, cascade='all, delete', foreign_keys=[_text_id])
 
     _pdf_id = Column(Integer, db.ForeignKey(Blob.id), info=NOT_AUDITABLE)
     pdf_blob = relationship(Blob, cascade='all, delete', foreign_keys=[_pdf_id])
 
     _preview_id = Column(Integer, db.ForeignKey(Blob.id), info=NOT_AUDITABLE)
-    preview_blob = relationship(Blob,
-                                cascade='all, delete',
-                                foreign_keys=[_preview_id])
+    preview_blob = relationship(
+        Blob, cascade='all, delete', foreign_keys=[_preview_id])
 
-    language = Column(Text,
-                      info=dict(searchable=True,
-                                index_to=[('language', wf.ID(stored=True))]))
+    language = Column(
+        Text,
+        info=dict(
+            searchable=True, index_to=[('language', wf.ID(stored=True))]))
     size = Column(Integer)
     page_num = Column(Integer, default=1)
 
@@ -596,8 +588,7 @@ class Document(BaseContent, PathAndSecurityIndexable):
 
     @property
     def antivirus_required(self):
-        """
-        True if antivirus doesn't need to be run
+        """True if antivirus doesn't need to be run.
         """
         required = current_app.config['ANTIVIRUS_CHECK_REQUIRED']
         return required and (not self.antivirus_scanned or
@@ -605,8 +596,7 @@ class Document(BaseContent, PathAndSecurityIndexable):
 
     @property
     def antivirus_ok(self):
-        """
-        True if user can safely access document content
+        """True if user can safely access document content.
         """
         required = current_app.config['ANTIVIRUS_CHECK_REQUIRED']
         if required:
@@ -628,23 +618,25 @@ class Document(BaseContent, PathAndSecurityIndexable):
 
     @property
     def pdf(self):
+        if self.pdf_blob:
+            assert isinstance(self.pdf_blob.value, bytes)
         return self.pdf_blob and self.pdf_blob.value
 
     @pdf.setter
     def pdf(self, value):
-        assert isinstance(value, str)
+        assert isinstance(value, bytes)
         self.pdf_blob = Blob()
         self.pdf_blob.value = value
 
     # `text` is an Unicode value.
     @property
     def text(self):
-        return (self.text_blob.value.decode("utf8") if
-                self.text_blob is not None else u'')
+        return (self.text_blob.value.decode("utf8")
+                if self.text_blob is not None else u'')
 
     @text.setter
     def text(self, value):
-        assert isinstance(value, unicode)
+        assert isinstance(value, text_type)
         self.text_blob = Blob()
         self.text_blob.value = value.encode("utf8")
 
@@ -660,7 +652,7 @@ class Document(BaseContent, PathAndSecurityIndexable):
     @extra_metadata.setter
     def extra_metadata(self, extra_metadata):
         self._extra_metadata = extra_metadata
-        self.extra_metadata_json = unicode(json.dumps(extra_metadata))
+        self.extra_metadata_json = text_type(json.dumps(extra_metadata))
 
     # TODO: or use SQLAlchemy alias?
     @property
@@ -693,10 +685,9 @@ class Document(BaseContent, PathAndSecurityIndexable):
 
     @lock.setter
     def lock(self, user):
-        """
-        Allow to do `document.lock = user` to set a lock for user
+        """Allow to do `document.lock = user` to set a lock for user.
 
-        If user is None, the lock is released
+        If user is None, the lock is released.
         """
         if user is None:
             del self.lock
@@ -706,9 +697,9 @@ class Document(BaseContent, PathAndSecurityIndexable):
 
     @lock.deleter
     def lock(self):
-        """
-        Remove lock, if any. `del document.lock` can be safely done even if no lock
-        is set.
+        """Remove lock, if any.
+
+        `del document.lock` can be safely done even if no lock is set.
         """
         meta = self.meta.setdefault('abilian.sbe.documents', {})
         if 'lock' in meta:
@@ -740,6 +731,7 @@ def icon_for(content_type):
 
     return icon_url('bin.png')
 
+
 # Async conversion
 _async_data = threading.local()
 
@@ -775,5 +767,5 @@ def setup_listener():
     if getattr(_trigger_conversion_tasks, mark_attr, False):
         return
 
-    event.listen(Session, "after_commit", _trigger_conversion_tasks)
+    listen(Session, "after_commit", _trigger_conversion_tasks)
     setattr(_trigger_conversion_tasks, mark_attr, True)
