@@ -1,16 +1,16 @@
 # coding=utf-8
 """
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 from datetime import datetime
-from urllib import quote
 
 import sqlalchemy as sa
-from flask import (current_app, flash, g, make_response, redirect,
-                   render_template, request)
+from flask import current_app, flash, g, make_response, redirect, \
+    render_template, request
 from flask_login import current_user
 from flask_mail import Message
+from six.moves.urllib.parse import quote
 from werkzeug.exceptions import BadRequest, NotFound
 
 from abilian.core.extensions import db, mail
@@ -28,16 +28,18 @@ from abilian.web.views import default_view
 from ..models import Document
 from ..repository import repository
 from ..tasks import convert_document_content, preview_document
-from .util import (breadcrumbs_for, check_manage_access, check_read_access,
-                   check_write_access, edit_object, get_document, match)
-from .views import documents
+from .util import breadcrumbs_for, check_manage_access, check_read_access, \
+    check_write_access, edit_object, get_document, match
+from .views import blueprint
 
-route = documents.route
+route = blueprint.route
 
 MAX_PREVIEW_SIZE = 1000
 
+__all__ = ()
 
-@default_view(documents, Document, id_attr='doc_id', kw_func=default_view_kw)
+
+@default_view(blueprint, Document, id_attr='doc_id', kw_func=default_view_kw)
 @route("/doc/<int:doc_id>")
 def document_view(doc_id):
     doc = get_document(doc_id)
@@ -56,12 +58,13 @@ def document_view(doc_id):
     has_preview = doc.has_preview()
     audit_entries = audit_service.entries_for(doc)
 
-    ctx = dict(doc=doc,
-               audit_entries=audit_entries,
-               breadcrumbs=bc,
-               folder=doc.parent,
-               has_preview=has_preview,
-               csrf_token=csrf.field())
+    ctx = dict(
+        doc=doc,
+        audit_entries=audit_entries,
+        breadcrumbs=bc,
+        folder=doc.parent,
+        has_preview=has_preview,
+        csrf_token=csrf.field())
     return render_template("documents/document.html", **ctx)
 
 
@@ -174,8 +177,9 @@ def checkin_checkout(doc_id):
 
 
 def preview_missing_image():
-    response = redirect(url_for('abilian_sbe_static',
-                                filename='images/preview_missing.png'))
+    response = redirect(
+        url_for(
+            'abilian_sbe_static', filename='images/preview_missing.png'))
     response.headers['Cache-Control'] = 'no-cache'
     return response
 
@@ -196,8 +200,8 @@ def document_preview_image(doc_id):
         size = MAX_PREVIEW_SIZE
 
     # compute image if size != standard document size
-    get_image = (converter.get_image if size == doc.preview_size else
-                 converter.to_image)
+    get_image = (converter.get_image
+                 if size == doc.preview_size else converter.to_image)
 
     content_type = "image/jpeg"
 
@@ -227,7 +231,8 @@ def document_preview_image(doc_id):
 
 @route("/doc/<int:doc_id>/refresh_preview")
 def refresh_preview(doc_id):
-    """ Force to compute a new preview. """
+    """Force to compute a new preview.
+    """
     doc = get_document(doc_id)
     if not doc:
         raise NotFound()
@@ -257,11 +262,12 @@ def document_send(doc_id):
     msg = Message(subject)
     msg.sender = g.user.email
     msg.recipients = [recipient]
-    msg.body = render_template_i18n('documents/mail_file_sent.txt',
-                                    sender_name=sender_name,
-                                    message=user_msg,
-                                    document_url=url_for(doc),
-                                    filename=doc.title)
+    msg.body = render_template_i18n(
+        'documents/mail_file_sent.txt',
+        sender_name=sender_name,
+        message=user_msg,
+        document_url=url_for(doc),
+        filename=doc.title)
 
     filename = doc.title
     msg.attach(filename, doc.content_type, doc.content)
@@ -279,14 +285,18 @@ def document_preview(doc_id):
         return "Waiting for antivirus to finish"
 
     if doc.content_type == "application/pdf":
-        return redirect(url_for(".document_view_pdf",
-                                community_id=g.community.slug,
-                                doc_id=doc.id))
+        return redirect(
+            url_for(
+                ".document_view_pdf",
+                community_id=g.community.slug,
+                doc_id=doc.id))
 
     else:
-        return redirect(url_for(".document_download",
-                                community_id=g.community.slug,
-                                doc_id=doc.id))
+        return redirect(
+            url_for(
+                ".document_download",
+                community_id=g.community.slug,
+                doc_id=doc.id))
 
 
 @route("/doc/<int:doc_id>/view_pdf")
@@ -295,10 +305,11 @@ def document_view_pdf(doc_id):
     if not doc.antivirus_ok:
         return "Waiting for antivirus to finish"
 
-    return render_template("documents/view_pdf.html",
-                           pdf_url=url_for(".document_download",
-                                           community_id=g.community.slug,
-                                           doc_id=doc.id))
+    return render_template(
+        "documents/view_pdf.html",
+        pdf_url=url_for(
+            ".document_download", community_id=g.community.slug, doc_id=doc.id))
+
 
 #
 # Tagging (currently not used!)
