@@ -1,7 +1,7 @@
 # coding=utf-8
 """
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function, unicode_literals
 
 import fnmatch
 import itertools
@@ -9,18 +9,19 @@ import logging
 import os
 import re
 import tempfile
-from cStringIO import StringIO
 from datetime import datetime
 from functools import partial
-from urllib import quote
+from io import StringIO
 from zipfile import ZipFile, is_zipfile
 
 import sqlalchemy as sa
 import whoosh.query as wq
-from flask import (Markup, current_app, flash, g, jsonify, make_response,
-                   redirect, render_template, render_template_string, request,
-                   send_file)
+from flask import Markup, current_app, flash, g, jsonify, make_response, \
+    redirect, render_template, render_template_string, request, send_file
+from flask._compat import text_type
+from six.moves.urllib.parse import quote
 from sqlalchemy import func
+from typing import Any, List
 from werkzeug.exceptions import InternalServerError
 from xlwt import Workbook, easyxf
 
@@ -37,13 +38,14 @@ from abilian.web.views import default_view
 from ..models import Document, Folder, icon_for, icon_url
 from ..repository import repository
 from ..search import reindex_tree
-from .util import (breadcrumbs_for, check_manage_access, check_read_access,
-                   check_write_access, create_document, edit_object,
-                   get_document, get_folder, get_new_filename,
-                   get_selected_objects)
-from .views import documents
+from .util import breadcrumbs_for, check_manage_access, check_read_access, \
+    check_write_access, create_document, edit_object, get_document, \
+    get_folder, get_new_filename, get_selected_objects
+from .views import blueprint
 
-route = documents.route
+route = blueprint.route
+
+__all__ = ()
 
 
 @route("/")
@@ -53,16 +55,17 @@ def index():
     return redirect(url)
 
 
-@default_view(documents, Folder, id_attr='folder_id', kw_func=default_view_kw)
+@default_view(blueprint, Folder, id_attr='folder_id', kw_func=default_view_kw)
 @route("/folder/<int:folder_id>")
 def folder_view(folder_id):
     folder = get_folder(folder_id)
     bc = breadcrumbs_for(folder)
     actions.context['object'] = folder
-    ctx = dict(folder=folder,
-               children=folder.filtered_children,
-               breadcrumbs=bc,
-               csrf_token=csrf.field(),)
+    ctx = dict(
+        folder=folder,
+        children=folder.filtered_children,
+        breadcrumbs=bc,
+        csrf_token=csrf.field())
     return render_template("documents/folder.html", **ctx)
 
 
@@ -79,9 +82,9 @@ def folder_json(folder_id):
     folders = result['folders'] = []
     bc = result['breadcrumbs'] = []
     subfolders = sorted(
-        (f
-         for f in folder.subfolders
-         if has_permission(g.user, READ, f, inherit=True)),
+        (f for f in folder.subfolders
+         if has_permission(
+             g.user, READ, f, inherit=True)),
         key=lambda f: f.title)
 
     parent = folder
@@ -93,8 +96,8 @@ def folder_json(folder_id):
 
         data = {
             'id': parent.id,
-            'url': folder_url(folder_id=parent.id,
-                              community_id=parent.community.slug),
+            'url': folder_url(
+                folder_id=parent.id, community_id=parent.community.slug),
             'title': parent.title,
         }
         bc.append(data)
@@ -110,8 +113,8 @@ def folder_json(folder_id):
     for folder in subfolders:
         data = {
             'id': folder.id,
-            'url': folder_url(folder_id=folder.id,
-                              community_id=folder.community.slug),
+            'url': folder_url(
+                folder_id=folder.id, community_id=folder.community.slug),
             'title': folder.title,
         }
         folders.append(data)
@@ -144,32 +147,31 @@ def permissions(folder_id):
     users_and_local_roles = [(user, role, repository.has_access(user, folder))
                              for user, role in local_roles_assignments
                              if isinstance(user, User)]
-    groups_and_local_roles = [t
-                              for t in local_roles_assignments
-                              if isinstance(t[0], Group)]
+    groups_and_local_roles = [
+        t for t in local_roles_assignments if isinstance(t[0], Group)
+    ]
 
     users_and_inherited_roles = groups_and_inherited_roles = ()
 
     if folder.inherit_security:
         inherited_roles_assignments = folder.get_inherited_roles_assignments()
         users_and_inherited_roles = [
-            (user, role, False)
-            for user, role in inherited_roles_assignments
+            (user, role, False) for user, role in inherited_roles_assignments
             if isinstance(user, User)
         ]
-        groups_and_inherited_roles = [t
-                                      for t in inherited_roles_assignments
-                                      if isinstance(t[0], Group)]
+        groups_and_inherited_roles = [
+            t for t in inherited_roles_assignments if isinstance(t[0], Group)
+        ]
 
     query = Group.query
     query = query.order_by(func.lower(Group.name))
     all_groups = query.all()
 
     class EntryPresenter(object):
-        _USER_FMT = (u'<a href="{{ url_for("social.user", user_id=user.id) }}">'
+        _USER_FMT = ('<a href="{{ url_for("social.user", user_id=user.id) }}">'
                      '{{ user.name }}</a>')
         _GROUP_FMT = (
-            u'<a href="{{ url_for("social.group_home", group_id=group.id)'
+            '<a href="{{ url_for("social.group_home", group_id=group.id)'
             ' }}">{{ group.name }}</a>')
 
         def __init__(self, e):
@@ -177,46 +179,49 @@ def permissions(folder_id):
             self.entry = e
             self.date = e.happened_at.strftime('%Y-%m-%d %H:%M')
             self.manager = render(
-                u'<img src="{{ user_photo_url(e.manager, size=16) }}" alt="" />'
+                '<img src="{{ user_photo_url(e.manager, size=16) }}" alt="" />'
                 '<a href="{{ url_for("social.user", user_id=e.manager_id) }}">'
                 '{{ e.manager.name }}</a>',
                 e=e)
 
             if e.op == e.SET_INHERIT:
-                msg = _(u'On {date}, {manager} has activated inheritance')
+                msg = _('On {date}, {manager} has activated inheritance')
             elif e.op == e.UNSET_INHERIT:
-                msg = _(u'On {date}, {manager} has deactivated inheritance')
+                msg = _('On {date}, {manager} has deactivated inheritance')
             elif e.op == e.GRANT:
-                msg = _(u'On {date}, {manager} has given role "{role}" to {principal}')
+                msg = _('On {date}, {manager} has given role "{role}" to {principal}')
             elif e.op == e.REVOKE:
-                msg = _(u'On {date}, {manager} has revoked role "{role}" from '
+                msg = _('On {date}, {manager} has revoked role "{role}" from '
                         '{principal}')
             else:
                 raise Exception("Unknown audit entry type %s" % e.op)
 
-            principal = u''
+            principal = ''
             if self.entry.user:
                 principal = render(self._USER_FMT, user=self.entry.user)
             elif self.entry.group:
                 principal = render(self._GROUP_FMT, group=self.entry.group)
 
-            self.msg = Markup(msg.format(date=self.date,
-                                         manager=self.manager,
-                                         role=self.entry.role,
-                                         principal=principal))
+            self.msg = Markup(
+                msg.format(
+                    date=self.date,
+                    manager=self.manager,
+                    role=self.entry.role,
+                    principal=principal))
 
     audit_entries = [EntryPresenter(e) for e in security.entries_for(folder)]
     csrf_token = csrf.field()
 
-    ctx = dict(folder=folder,
-               users_and_local_roles=users_and_local_roles,
-               users_and_inherited_roles=users_and_inherited_roles,
-               groups_and_local_roles=groups_and_local_roles,
-               groups_and_inherited_roles=groups_and_inherited_roles,
-               audit_entries=audit_entries,
-               csrf_token=csrf_token,
-               all_groups=all_groups,
-               breadcrumbs=bc)
+    ctx = dict(
+        folder=folder,
+        users_and_local_roles=users_and_local_roles,
+        users_and_inherited_roles=users_and_inherited_roles,
+        groups_and_local_roles=groups_and_local_roles,
+        groups_and_inherited_roles=groups_and_inherited_roles,
+        audit_entries=audit_entries,
+        csrf_token=csrf_token,
+        all_groups=all_groups,
+        breadcrumbs=bc)
 
     return render_template("documents/permissions.html", **ctx)
 
@@ -232,23 +237,26 @@ def permissions_update(folder_id):
     if action in ("activate_inheritance", "deactivate_inheritance"):
         inherit_security = (action == "activate_inheritance")
 
-        if not (inherit_security or
-                has_permission(g.user, 'manage',
-                               folder, inherit=False)):
+        if not (inherit_security or has_permission(
+                g.user, 'manage', folder, inherit=False)):
             # don't let user shoot himself in the foot
-            flash(_(u'You must have the "manager" local role on this folder in '
-                    'order to deactivate inheritance.'), u'error')
-            return redirect(url_for(".permissions",
-                                    folder_id=folder_id,
-                                    community_id=folder.community.slug))
+            flash(_('You must have the "manager" local role on this folder in '
+                    'order to deactivate inheritance.'), 'error')
+            return redirect(
+                url_for(
+                    ".permissions",
+                    folder_id=folder_id,
+                    community_id=folder.community.slug))
 
         security.set_inherit_security(folder, inherit_security)
         db.session.add(folder)
         reindex_tree(folder)
         db.session.commit()
-        return redirect(url_for(".permissions",
-                                folder_id=folder_id,
-                                community_id=folder.community.slug))
+        return redirect(
+            url_for(
+                ".permissions",
+                folder_id=folder_id,
+                community_id=folder.community.slug))
 
     elif action == "add-user-role":
         role = request.form.get("role").lower()
@@ -258,9 +266,11 @@ def permissions_update(folder_id):
         security.grant_role(user, role, folder)
         reindex_tree(folder)
         db.session.commit()
-        return redirect(url_for(".permissions",
-                                folder_id=folder_id,
-                                community_id=folder.community.slug))
+        return redirect(
+            url_for(
+                ".permissions",
+                folder_id=folder_id,
+                community_id=folder.community.slug))
 
     elif action == "add-group-role":
         role = request.form.get("role").lower()
@@ -270,9 +280,11 @@ def permissions_update(folder_id):
         security.grant_role(group, role, folder)
         reindex_tree(folder)
         db.session.commit()
-        return redirect(url_for(".permissions",
-                                folder_id=folder_id,
-                                community_id=folder.community.slug))
+        return redirect(
+            url_for(
+                ".permissions",
+                folder_id=folder_id,
+                community_id=folder.community.slug))
 
     else:
         action, args = request.form.items()[0]
@@ -288,18 +300,17 @@ def permissions_update(folder_id):
             security.ungrant_role(user, role, folder)
 
             if (user == g.user and role == 'manager' and not has_permission(
-                    g.user, 'manage', folder,
-                    inherit=True)):
+                    g.user, 'manage', folder, inherit=True)):
 
                 transaction.rollback()
-                flash(_(u'Cannot remove "manager" local role for yourself: you '
+                flash(_('Cannot remove "manager" local role for yourself: you '
                         'don\'t have "manager" role (either by security inheritance '
                         'or by group membership)'),
                       'error')
             else:
                 reindex_tree(folder)
                 transaction.commit()
-                flash(_(u"Role {role} for user {user} removed on folder {folder}"
+                flash(_("Role {role} for user {user} removed on folder {folder}"
                 ).format(role=role, user=user.name, folder=folder.name),
                       "success")
         elif action == 'delete-group-role':
@@ -310,24 +321,25 @@ def permissions_update(folder_id):
             security.ungrant_role(group, role, folder)
 
             if (role == 'manager' and not has_permission(
-                    g.user, 'manage', folder,
-                    inherit=True)):
+                    g.user, 'manage', folder, inherit=True)):
                 transaction.rollback()
-                flash(_(u'Cannot remove "manager" local role for group "{group}": you'
+                flash(_('Cannot remove "manager" local role for group "{group}": you'
                         ' don\'t have "manager" role by security inheritance or by '
                         'local role').format(group=group.name),
                       'error')
             else:
-                flash(_(u"Role {role} for group {group} removed on folder {folder}"
+                flash(_("Role {role} for group {group} removed on folder {folder}"
                 ).format(role=role, group=group.name, folder=folder.name),
                       "success")
                 reindex_tree(folder)
                 transaction.commit()
 
         db.session.commit()
-        return redirect(url_for(".permissions",
-                                folder_id=folder_id,
-                                community_id=folder.community.slug))
+        return redirect(
+            url_for(
+                ".permissions",
+                folder_id=folder_id,
+                community_id=folder.community.slug))
 
 
 @route("/folder/<int:folder_id>/permissions_export")
@@ -340,14 +352,14 @@ def permissions_export(folder_id):
     ws = wb.add_sheet("Sheet 1")
 
     cols = [
-        (u'Accès', 20),
-        (u'Identifiant', 40),
-        (u'Prénom', 14),
-        (u'Nom', 20),
-        (u'Rôle', None),
-        (u'Local', None),
-        (u'Héritage', None),
-        (u'Communauté', 60),
+        ('Accès', 20),
+        ('Identifiant', 40),
+        ('Prénom', 14),
+        ('Nom', 20),
+        ('Rôle', None),
+        ('Local', None),
+        ('Héritage', None),
+        ('Communauté', 60),
     ]
 
     # styling
@@ -384,7 +396,7 @@ def permissions_export(folder_id):
 
         for c, value in enumerate(row):
             if isinstance(value, Role):
-                value = unicode(value)
+                value = text_type(value)
             ws.write(r + row_offset, c, value)
 
         # data grouping exit
@@ -400,10 +412,10 @@ def permissions_export(folder_id):
 
     response = make_response(fd.getvalue())
     response.headers['content-type'] = 'application/ms-excel'
-    folder_name = folder.title.replace(u' ', u'_')
+    folder_name = folder.title.replace(' ', '_')
     file_date = datetime.now().strftime("%Y-%m-%d-%H:%M:%S")
-    filename = u'permissions-{}-{}.xls'.format(folder_name, file_date)
-    content_disposition = u'attachment;filename="{}"'.format(filename)
+    filename = 'permissions-{}-{}.xls'.format(folder_name, file_date)
+    content_disposition = 'attachment;filename="{}"'.format(filename)
     response.headers['content-disposition'] = content_disposition
     return response
 
@@ -417,8 +429,8 @@ def iter_permissions(folder, user):
 
     community = folder.path
     local_roles = frozenset(folder.get_local_roles_assignments())
-    inherited_roles = frozenset((folder.get_inherited_roles_assignments() if
-                                 folder.inherit_security else []))
+    inherited_roles = frozenset((folder.get_inherited_roles_assignments()
+                                 if folder.inherit_security else []))
 
     result = {}
     for principal, role in (local_roles | inherited_roles):
@@ -427,13 +439,13 @@ def iter_permissions(folder, user):
         data['inherit'] = (principal, role) in inherited_roles
 
     def _sort_key(item):
-        """ Sorts by name, groups first. """
+        """Sorts by name, groups first."""
         principal = item[0][0]
         is_user = isinstance(principal, User)
-        item_key = [is_user]
+        item_key = [is_user]  # type: List[Any]
         if is_user:
-            last_name = principal.last_name if principal.last_name else u''
-            first_name = principal.first_name if principal.first_name else u''
+            last_name = principal.last_name if principal.last_name else ''
+            first_name = principal.first_name if principal.first_name else ''
             item_key.append(last_name.lower())
             item_key.append(first_name.lower())
         else:
@@ -443,8 +455,8 @@ def iter_permissions(folder, user):
     for (p, role), data in sorted(result.items(), key=_sort_key):
         is_user = isinstance(p, User)
         has_access = False if is_user else '*'
-        identifier = p.email if is_user else u'* Group *'
-        first_name = p.first_name if is_user else u'-'
+        identifier = p.email if is_user else '* Group *'
+        first_name = p.first_name if is_user else '-'
         last_name = p.last_name if is_user else p.name
         local = data['local']
         inherit = data['inherit']
@@ -452,8 +464,7 @@ def iter_permissions(folder, user):
         yield (has_access, identifier, first_name, last_name, role, local,
                inherit, community)
 
-    subfolders = (f
-                  for f in folder.subfolders
+    subfolders = (f for f in folder.subfolders
                   if security.has_permission(user, "manage", folder))
 
     for subfolder in subfolders:
@@ -499,8 +510,8 @@ def folder_post(folder_id):
         # Probably an error or a hack attempt.
         # Logger will inform sentry if enabled
         logger = logging.getLogger(__name__)
-        logger.error(u"Unknown folder action.", extra={'stack': True})
-        flash(_(u"Unknown action."), "error")
+        logger.error("Unknown folder action.", extra={'stack': True})
+        flash(_("Unknown action."), "error")
         return redirect(url_for(folder))
 
 
@@ -511,20 +522,22 @@ def folder_edit(folder):
 
     if changed:
         db.session.commit()
-        flash(_(u"Folder properties successfully edited."), "success")
+        flash(_("Folder properties successfully edited."), "success")
     else:
-        flash(_(u"You didn't change any property."), "success")
+        flash(_("You didn't change any property."), "success")
     return redirect(url_for(folder))
 
 
-ARCHIVE_IGNORE_FILES = {u'__MACOSX/*', u'.DS_Store',}
+ARCHIVE_IGNORE_FILES_GLOBS = {'__MACOSX/*', '.DS_Store'}
 # translates patterns to match with any parent directory ((*/)?pattern should
 # match)
-ARCHIVE_IGNORE_FILES = {re.compile(u'(?:.*\\/)?' + fnmatch.translate(pattern))
-                        for pattern in ARCHIVE_IGNORE_FILES}
+ARCHIVE_IGNORE_FILES = {
+    re.compile('(?:.*\\/)?' + fnmatch.translate(pattern))
+    for pattern in ARCHIVE_IGNORE_FILES_GLOBS
+}
 
 # skip directory names. Directory will be created only if they contains files
-ARCHIVE_IGNORE_FILES.add(re.compile(fnmatch.translate(u'*/')))
+ARCHIVE_IGNORE_FILES.add(re.compile(fnmatch.translate('*/')))
 
 
 def explore_archive(fd, filename=None, uncompress=False):
@@ -538,8 +551,8 @@ def explore_archive(fd, filename=None, uncompress=False):
     if filename is None:
         filename = fd.filename
 
-    if not isinstance(filename, unicode):
-        filename = unicode(fd.filename, errors='ignore')
+    if not isinstance(filename, text_type):
+        filename = text_type(fd.filename, errors='ignore')
 
     if not uncompress:
         yield [], fd
@@ -558,11 +571,12 @@ def explore_archive(fd, filename=None, uncompress=False):
                     except UnicodeDecodeError:
                         filename = filename.decode('cp437')
 
-                if any(pattern.match(filename) is not None
-                       for pattern in ARCHIVE_IGNORE_FILES):
+                if any(
+                        pattern.match(filename) is not None
+                        for pattern in ARCHIVE_IGNORE_FILES):
                     continue
 
-                filepath = filename.split(u'/')
+                filepath = filename.split('/')
                 filename = filepath.pop()
                 zip_fd = archive.open(zipinfo, 'r')
                 setattr(zip_fd, 'filename', filename)
@@ -582,8 +596,8 @@ def upload_new(folder):
     path_cache = {}  # mapping folder path in zip: folder instance
 
     for upload_fd in fds:
-        for filepath, fd in explore_archive(upload_fd,
-                                            uncompress=uncompress_files):
+        for filepath, fd in explore_archive(
+                upload_fd, uncompress=uncompress_files):
             folder = base_folder
             parts = []
             # traverse to final directory, create intermediate if necessary. Folders
@@ -591,7 +605,7 @@ def upload_new(folder):
             # track of this
             for subfolder_name in filepath:
                 parts.append(subfolder_name)
-                path = u'/'.join(parts)
+                path = '/'.join(parts)
                 if path in path_cache:
                     folder = path_cache[path]
                     continue
@@ -611,8 +625,8 @@ def upload_new(folder):
             created_count += 1
 
     flash(
-        _n(u"One new document successfully uploaded",
-           u"%(num)d new document successfully uploaded",
+        _n("One new document successfully uploaded",
+           "%(num)d new document successfully uploaded",
            num=created_count),
         "success")
 
@@ -624,9 +638,9 @@ def download_multiple(folder):
     folders, docs = get_selected_objects(folder)
 
     def rel_path(path, content):
-        return u'{}/{}'.format(path, content.title)
+        return '{}/{}'.format(path, content.title)
 
-    def zip_folder(zipfile, folder, path=u''):
+    def zip_folder(zipfile, folder, path=''):
         for doc in folder.documents:
             doc_path = rel_path(path, doc)
             zipfile.writestr(doc_path, doc.content)
@@ -658,7 +672,7 @@ def download_multiple(folder):
         zip_fn,
         mimetype="application/zip",
         as_attachment=True,
-        attachment_filename=quote(folder.title.encode("utf8") + ".zip"))
+        attachment_filename=quote(folder.title.encode("utf8") + b".zip"))
     resp.headers.add('Content-Length', str(size))
     return resp
 
@@ -671,17 +685,14 @@ def delete_multiple(folder):
     for obj in docs + folders:
         app = current_app._get_current_object()
         community = g.community._model
-        activity.send(app,
-                      actor=g.user,
-                      verb="delete",
-                      object=obj,
-                      target=community)
+        activity.send(
+            app, actor=g.user, verb="delete", object=obj, target=community)
         repository.delete_object(obj)
 
     if docs + folders:
         db.session.commit()
         if docs and folders:
-            msg = _(u"%(file_num)d files and %(folder_num)d folders sucessfully "
+            msg = _("%(file_num)d files and %(folder_num)d folders sucessfully "
                     "deleted.", file_num=len(docs), folder_num=len(folders))
         elif docs and not folders:
             msg = _n("1 file sucessfully deleted.",
@@ -694,7 +705,7 @@ def delete_multiple(folder):
 
         flash(msg, "success")
     else:
-        flash(_(u"No object deleted"), "error")
+        flash(_("No object deleted"), "error")
 
     return redirect(url_for(folder))
 
@@ -706,32 +717,31 @@ def move_multiple(folder):
     current_folder_url = url_for(folder)
 
     if not (count_f + count_d):
-        flash(_(u'Move elements: no elements selected.'), 'info')
+        flash(_('Move elements: no elements selected.'), 'info')
         return redirect(current_folder_url)
 
     try:
         target_folder_id = int(request.form.get('target-folder'))
     except ValueError:
-        flash(_(u'Move elements: no destination folder selected. Aborted.'),
+        flash(_('Move elements: no destination folder selected. Aborted.'),
               'error')
         return redirect(current_folder_url)
 
     target_folder = repository.get_folder_by_id(target_folder_id)
 
     if folder == target_folder:
-        flash(_(u'Move elements: source and destination folder are identical,'
+        flash(_('Move elements: source and destination folder are identical,'
                 ' nothing done.'), 'error')
         return redirect(current_folder_url)
 
     if not security.has_permission(g.user, 'write', folder, inherit=True):
         # this should not happen: this is just defensive programming
-        flash(_(u'You are not allowed to move elements from this folder'), 'error')
+        flash(_('You are not allowed to move elements from this folder'), 'error')
         return redirect(current_folder_url)
 
     if not security.has_permission(
-            g.user, 'write', target_folder,
-            inherit=True):
-        flash(_(u'You are not allowed to write in folder "{folder}"'
+            g.user, 'write', target_folder, inherit=True):
+        flash(_('You are not allowed to write in folder "{folder}"'
         ).format(folder=target_folder.title),
               'error')
         return redirect(current_folder_url)
@@ -745,7 +755,7 @@ def move_multiple(folder):
     f = target_folder
     while f:
         if f in folders:
-            flash(_(u'Move elements: destination folder is included in moved '
+            flash(_('Move elements: destination folder is included in moved '
                     'elements. Moved nothing.'), 'error')
             return redirect(url_for(folder))
         f = f.parent
@@ -761,23 +771,23 @@ def move_multiple(folder):
     if exist_in_dest:
         # items existing in destination: cancel operation
         db.session.rollback()
-        msg = _(u'Move elements: canceled, some elements exists in destination '
-                u'folder: {elements}')
-        elements = u', '.join(u'"{}"'.format(i.title) for i in exist_in_dest)
+        msg = _('Move elements: canceled, some elements exists in destination '
+                'folder: {elements}')
+        elements = ', '.join('"{}"'.format(i.title) for i in exist_in_dest)
         flash(msg.format(elements=elements), 'error')
         return redirect(current_folder_url)
 
     db.session.commit()
 
-    msg_f = (_n(u'1 folder', u'{count} folders', count_f)
+    msg_f = (_n('1 folder', '{count} folders', count_f)
              if count_f
-             else _(u'0 folder')).format(count=count_f)
+             else _('0 folder')).format(count=count_f)
 
-    msg_d = (_n(u'1 document', u'{count} documents', count_d)
+    msg_d = (_n('1 document', '{count} documents', count_d)
              if count_d
-             else _(u'0 document')).format(count=count_d)
+             else _('0 document')).format(count=count_d)
 
-    msg = _(u'{folders} and {documents} moved to {target}').format(
+    msg = _('{folders} and {documents} moved to {target}').format(
         folders=msg_f, documents=msg_d, target=target_folder.title)
     flash(msg, 'success')
 
@@ -787,8 +797,8 @@ def move_multiple(folder):
 def create_subfolder(folder):
     check_write_access(folder)
 
-    title = request.form.get("title", u"")
-    description = request.form.get("description", u"")
+    title = request.form.get("title", "")
+    description = request.form.get("description", "")
     subfolder = folder.create_subfolder(title)
     subfolder.description = description
 
@@ -823,19 +833,19 @@ def check_valid_name():
     obj = get_object(object_id)
     check_read_access(obj)
 
-    if action == u'new':
+    if action == 'new':
         parent = obj
-        help_text = _(u'An element named "{name}" is already present in folder')
-    elif action in (u'folder-edit', u'document-edit'):
+        help_text = _('An element named "{name}" is already present in folder')
+    elif action in ('folder-edit', 'document-edit'):
         parent = obj.parent
-        help_text = _(u'Cannot rename: "{name}" is already present in parent '
+        help_text = _('Cannot rename: "{name}" is already present in parent '
                       'folder')
     else:
         raise InternalServerError()
 
     existing = set((e.title for e in parent.children))
 
-    if action in (u'folder-edit', u'document-edit'):
+    if action in ('folder-edit', 'document-edit'):
         try:
             existing.remove(obj.title)
         except KeyError:
@@ -855,20 +865,23 @@ def descendants_view(folder_id):
     bc = breadcrumbs_for(folder)
     actions.context['object'] = folder
 
-    root_path_ids = folder._indexable_parent_ids + u'/{}'.format(folder.id)
+    root_path_ids = folder._indexable_parent_ids + '/{}'.format(folder.id)
     svc = current_app.services['indexing']
-    filters = wq.And([wq.Term('community_id', folder.community.id), wq.Term(
-        'parent_ids', root_path_ids), wq.Or([wq.Term(
-            'object_type', Folder.entity_type), wq.Term(
-                'object_type', Document.entity_type)])])
 
-    results = svc.search(u'', filter=filters, limit=None)
+    # yapf: disable
+    filters = wq.And([wq.Term('community_id', folder.community.id),
+                      wq.Term('parent_ids', root_path_ids),
+                      wq.Or([wq.Term('object_type', Folder.entity_type),
+                             wq.Term('object_type', Document.entity_type)])])
+    # yapf: enable
+
+    results = svc.search('', filter=filters, limit=None)
     by_path = {}
     owner_ids = set()
     for hit in results:
         by_path.setdefault(hit['parent_ids'], []).append(hit)
-        owner_type, owner_id = hit['owner'].split(u':')
-        if owner_type == u'user':
+        owner_type, owner_id = hit['owner'].split(':')
+        if owner_type == 'user':
             try:
                 owner_id = int(owner_id)
                 owner_ids.add(owner_id)
@@ -877,8 +890,8 @@ def descendants_view(folder_id):
 
     for children in by_path.values():
         children.sort(
-            key=
-            lambda hit: (hit['object_type'] != Folder.entity_type, hit['name'].lower()))
+            key=lambda hit: (hit['object_type'] != Folder.entity_type, hit['name'].lower())
+        )
 
     descendants = []
 
@@ -887,28 +900,30 @@ def descendants_view(folder_id):
 
         for child in children:
             is_folder = child['object_type'] == Folder.entity_type
-            type_letter = u'F' if is_folder else u'D'
+            type_letter = 'F' if is_folder else 'D'
             descendants.append((level, type_letter, child))
 
             if is_folder:
-                path_id = child['parent_ids'] + u'/{}'.format(child['id'])
+                path_id = child['parent_ids'] + '/{}'.format(child['id'])
                 visit(path_id, level + 1)
 
     visit(root_path_ids, 0)
 
     owners = dict()
-    owners_q = User.query \
+    owners_query = User.query \
         .filter(User.id.in_(owner_ids)) \
         .add_column(sa.sql.func.concat('user:', User.id).label('key'))
-    for user, key in owners_q:
+    for user, key in owners_query:
         owners[key] = user
 
-    ctx = dict(folder=folder,
-               descendants=descendants,
-               owners=owners,
-               breadcrumbs=bc,
-               get_icon=get_icon_for_hit,
-               csrf_token=csrf.field(),)
+    ctx = {
+        'folder': folder,
+        'descendants': descendants,
+        'owners': owners,
+        'breadcrumbs': bc,
+        'get_icon': get_icon_for_hit,
+        'csrf_token': csrf.field(),
+    }
     return render_template("documents/descendants.html", **ctx)
 
 
