@@ -5,18 +5,18 @@ Models for the Forum.
 Note: a few features are planned but not implemented yet, and are commented
 out.
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 from itertools import chain
 
-import sqlalchemy as sa
 from sqlalchemy import Column, ForeignKey, Integer, Unicode, UnicodeText
+from sqlalchemy.event import listens_for
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.orm import backref, relationship
 
 from abilian.core.entities import SEARCHABLE, Entity
-from abilian.sbe.apps.communities.models import (Community, CommunityIdColumn,
-                                                 community_content)
+from abilian.sbe.apps.communities.models import Community, CommunityIdColumn, \
+    community_content
 from abilian.sbe.apps.documents.models import BaseContent, CmisObject
 from abilian.services.indexing.adapter import SAAdapter
 
@@ -46,14 +46,12 @@ class Thread(Entity):
     community = relationship(
         Community,
         primaryjoin=(community_id == Community.id),
-        backref=backref('threads', cascade="all, delete-orphan"))
+        backref=backref(
+            'threads', cascade="all, delete-orphan"))
 
     #: The thread title (aka subject)
-    _title = Column('title',
-                    Unicode(255),
-                    nullable=False,
-                    default=u"",
-                    info=SEARCHABLE)
+    _title = Column(
+        'title', Unicode(255), nullable=False, default=u"", info=SEARCHABLE)
 
     # title is defined has an hybrid property to allow name <-> title sync (2 way)
     @hybrid_property
@@ -68,15 +66,17 @@ class Thread(Entity):
         if self.name != title:
             self.name = title
 
-    posts = relationship('Post',
-                         primaryjoin='Thread.id == Post.thread_id',
-                         order_by='Post.created_at',
-                         cascade="all, delete-orphan",
-                         back_populates='thread',)
+    posts = relationship(
+        'Post',
+        primaryjoin='Thread.id == Post.thread_id',
+        order_by='Post.created_at',
+        cascade="all, delete-orphan",
+        back_populates='thread',)
 
     @property
     def closed(self):
-        """True if this thread doesn't accept more posts."""
+        """True if this thread doesn't accept more posts.
+        """
         return self.meta.get('abilian.sbe.forum', {}).get('closed', False)
 
     @closed.setter
@@ -94,10 +94,10 @@ class Thread(Entity):
         return post
 
 
-@sa.event.listens_for(Thread.name, "set", active_history=True)
+@listens_for(Thread.name, "set", active_history=True)
 def _thread_sync_name_title(entity, new_value, old_value, initiator):
-    """
-    Synchronize thread name -> title.
+    """Synchronize thread name -> title.
+
     thread.title -> name is done via hybrid_property, avoiding infinite
     loop (since "set" is received before attribute has received value)
     """
@@ -116,9 +116,8 @@ class Post(Entity):
 
     #: The thread this post belongs to
     thread_id = Column(ForeignKey(Thread.id), nullable=False)
-    thread = relationship(Thread,
-                          foreign_keys=thread_id,
-                          back_populates='posts')
+    thread = relationship(
+        Thread, foreign_keys=thread_id, back_populates='posts')
 
     #: The post this post is a reply to, if any (currently not used)
     parent_post_id = Column(ForeignKey("forum_post.id"), nullable=True)
@@ -126,10 +125,10 @@ class Post(Entity):
 
     #: Markup type (Markdown, Textile...)
     # TODO: markup langage selection + default
-    #markup_type = Column(String, default="Markdown")
+    # markup_type = Column(String, default="Markdown")
 
     #: Source (markup) for the post
-    #body_src = Column(UnicodeText, default=u"", nullable=False)
+    # body_src = Column(UnicodeText, default=u"", nullable=False)
 
     #: HTML rendering of the post
     body_html = Column(UnicodeText, default=u"", nullable=False)
@@ -144,7 +143,8 @@ class Post(Entity):
 
 
 class ThreadIndexAdapter(SAAdapter):
-    """Index a thread and its posts."""
+    """Index a thread and its posts.
+    """
 
     @staticmethod
     def can_adapt(obj_cls):
@@ -152,15 +152,16 @@ class ThreadIndexAdapter(SAAdapter):
 
     def get_document(self, obj):
         kw = super(ThreadIndexAdapter, self).get_document(obj)
-        kw['text'] = u' '.join(chain(
-            (kw['text'],), [p.body_html for p in obj.posts]))
+        kw['text'] = u' '.join(
+            chain((kw['text'],), [p.body_html for p in obj.posts]))
         return kw
 
 
 # event listener to sync name with thread's name
-@sa.event.listens_for(Thread.name, "set", active_history=True)
+@listens_for(Thread.name, "set", active_history=True)
 def _thread_sync_name(thread, new_value, old_value, initiator):
-    """Synchronize name with thread's name."""
+    """Synchronize name with thread's name.
+    """
     if new_value == old_value:
         return new_value
 
@@ -169,20 +170,22 @@ def _thread_sync_name(thread, new_value, old_value, initiator):
     return new_value
 
 
-@sa.event.listens_for(Post.thread, "set", active_history=True)
+@listens_for(Post.thread, "set", active_history=True)
 def _thread_change_sync_name(post, new_thread, old_thread, initiator):
-    """Change name on thread change."""
+    """Change name on thread change.
+    """
     if new_thread == old_thread or new_thread is None:
         return new_thread
     post.name = new_thread.name
     return new_thread
 
 
-@sa.event.listens_for(Thread.posts, 'append')
-@sa.event.listens_for(Thread.posts, 'remove')
-@sa.event.listens_for(Thread.posts, 'set')
+@listens_for(Thread.posts, 'append')
+@listens_for(Thread.posts, 'remove')
+@listens_for(Thread.posts, 'set')
 def _guard_closed_thread_collection(thread, value, *args):
-    """Prevent add/remove/replace posts on a closed thread."""
+    """Prevent add/remove/replace posts on a closed thread.
+    """
     if isinstance(thread, Post):
         thread = thread.thread
         if thread is None:
@@ -195,14 +198,16 @@ def _guard_closed_thread_collection(thread, value, *args):
 
 
 class PostAttachment(BaseContent, CmisObject):
-    __tablename__ = None
+    __tablename__ = None  # type: str  # type: str
     __mapper_args__ = {'polymorphic_identity': 'forum_post_attachment'}
     sbe_type = 'forum_post:attachment'
 
     _post_id = Column(Integer, ForeignKey(Post.id), nullable=True)
-    post = relationship(Post,
-                        primaryjoin=(_post_id == Post.id),
-                        backref=backref('attachments',
-                                        lazy='select',
-                                        order_by='PostAttachment.name',
-                                        cascade='all, delete-orphan'))
+    post = relationship(
+        Post,
+        primaryjoin=(_post_id == Post.id),
+        backref=backref(
+            'attachments',
+            lazy='select',
+            order_by='PostAttachment.name',
+            cascade='all, delete-orphan'))
