@@ -2,13 +2,14 @@
 """
 Celery tasks related to document transformation and preview.
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 import base64
 import hashlib
 import mailbox
 import re
 from os.path import expanduser
+from pathlib import Path
 
 import bleach
 import chardet
@@ -19,7 +20,7 @@ from flask import current_app, g
 from flask_babel import get_locale
 from flask_mail import Message
 from itsdangerous import Serializer
-from pathlib import Path
+from six import text_type
 
 from abilian.core.celery import periodic_task
 from abilian.core.extensions import db, mail
@@ -47,7 +48,8 @@ def init_app(app):
 
 @shared_task()
 def send_post_by_email(post_id):
-    """Send a post to community members by email."""
+    """Send a post to community members by email.
+    """
     from .models import Post
 
     with current_app.test_request_context('/send_post_by_email'):
@@ -62,8 +64,9 @@ def send_post_by_email(post_id):
                     community.name)
 
         CHUNK_SIZE = 20
-        members_id = [member.id
-                      for member in community.members if member.can_login]
+        members_id = [
+            member.id for member in community.members if member.can_login
+        ]
         chunk = []
         for idx, member_id in enumerate(members_id):
             chunk.append(member_id)
@@ -103,8 +106,8 @@ def batch_send_post_to_users(post_id, members_id, failed_ids=None):
     successfully_sent = []
     thread = post.thread
     community = thread.community
-    user_filter = (User.id.in_(members_id) if len(members_id) > 1 else
-                   User.id == members_id[0])
+    user_filter = (User.id.in_(members_id)
+                   if len(members_id) > 1 else User.id == members_id[0])
     users = User.query.filter(user_filter).all()
 
     for user in users:
@@ -124,14 +127,15 @@ def batch_send_post_to_users(post_id, members_id, failed_ids=None):
             # 5 minutes * (2** retry count)
             countdown = 300 * 2**batch_send_post_to_users.request.retries
             batch_send_post_to_users.retry(
-                [post_id, list(failed)],
-                countdown=countdown)
+                [post_id, list(failed)], countdown=countdown)
         else:
             batch_send_post_to_users.apply_async([post_id, list(failed)])
 
-    return {'post_id': post_id,
-            'successfully_sent': successfully_sent,
-            'failed': list(failed),}
+    return {
+        'post_id': post_id,
+        'successfully_sent': successfully_sent,
+        'failed': list(failed),
+    }
 
 
 def build_local_part(name, uid):
@@ -141,10 +145,10 @@ def build_local_part(name, uid):
     tag = current_app.config['MAIL_ADDRESS_TAG_CHAR']
     key = current_app.config['SECRET_KEY']
     serializer = Serializer(key)
-    signature = serializer.dumps(uid.decode('utf-8'))
+    signature = serializer.dumps(uid)
     digest = hashlib.md5(signature).digest()
     digest = base64.b32encode(digest).split('=', 1)[0]  # remove base32 padding
-    digest = unicode(digest)
+    # digest = unicode(digest)
     local_part = name + tag + uid + u'-' + digest
 
     if len(local_part) > 64:
@@ -219,12 +223,10 @@ def send_post_to_user(community, post, member):
     SERVER_NAME = config.get('SERVER_NAME', u'example.com')
     list_id = u'"{} forum" <forum.{}.{}>'.format(community.name, community.slug,
                                                  SERVER_NAME)
-    forum_url = url_for('forum.index',
-                        community_id=community.slug,
-                        _external=True)
-    forum_archive = url_for('forum.archives',
-                            community_id=community.slug,
-                            _external=True)
+    forum_url = url_for(
+        'forum.index', community_id=community.slug, _external=True)
+    forum_archive = url_for(
+        'forum.archives', community_id=community.slug, _external=True)
 
     extra_headers = {
         'List-Id': list_id,
@@ -238,16 +240,18 @@ def send_post_to_user(community, post, member):
         name = sender.rsplit('@', 1)[0]
         domain = sender.rsplit('@', 1)[1]
         replyto = build_reply_email_address(name, post, member, domain)
-        msg = Message(subject,
-                      sender=sender,
-                      recipients=[recipient],
-                      reply_to=replyto,
-                      extra_headers=extra_headers)
+        msg = Message(
+            subject,
+            sender=sender,
+            recipients=[recipient],
+            reply_to=replyto,
+            extra_headers=extra_headers)
     else:
-        msg = Message(subject,
-                      sender=sender,
-                      recipients=[recipient],
-                      extra_headers=extra_headers)
+        msg = Message(
+            subject,
+            sender=sender,
+            recipients=[recipient],
+            extra_headers=extra_headers)
 
     msg.body = render_template_i18n(
         "forum/mail/new_message.txt",
@@ -268,8 +272,9 @@ def send_post_to_user(community, post, member):
     try:
         mail.send(msg)
     except:
-        logger.error("Send mail to user failed",
-                     exc_info=True)  # log to sentry if enabled
+        logger.error(
+            "Send mail to user failed",
+            exc_info=True)  # log to sentry if enabled
 
 
 def extract_content(payload, marker):
@@ -280,15 +285,17 @@ def extract_content(payload, marker):
 
 
 def validate_html(payload):
-    return bleach.clean(payload,
-                        tags=ALLOWED_TAGS,
-                        attributes=ALLOWED_ATTRIBUTES,
-                        styles=ALLOWED_STYLES,
-                        strip=True).strip()
+    return bleach.clean(
+        payload,
+        tags=ALLOWED_TAGS,
+        attributes=ALLOWED_ATTRIBUTES,
+        styles=ALLOWED_STYLES,
+        strip=True).strip()
 
 
 def add_paragraph(newpost):
-    """Add surrounding <p>newpost</p> if necessary."""
+    """Add surrounding <p>newpost</p> if necessary.
+    """
 
     newpost = newpost.strip()
     if not newpost.startswith(u'<p>'):
@@ -297,7 +304,8 @@ def add_paragraph(newpost):
 
 
 def clean_html(newpost):
-    """Clean leftover empty blockquotes."""
+    """Clean leftover empty blockquotes.
+    """
 
     clean = re.sub(r"(<blockquote.*?<p>.*?</p>.*?</blockquote>)",
                    '',
@@ -318,10 +326,11 @@ def clean_html(newpost):
 
 
 def decode_payload(part):
-    """Get the payload and decode (base64 & quoted printable)."""
+    """Get the payload and decode (base64 & quoted printable).
+    """
 
     payload = part.get_payload(decode=True)
-    if not (isinstance(payload, unicode)):
+    if not (isinstance(payload, text_type)):
         # What about other encodings? -> using chardet
         if part.get_content_charset() is None:
             found = chardet.detect(payload)
@@ -352,9 +361,11 @@ def process(message, marker):
             content[part.get_content_subtype()] = payload
 
         if content_disp is not None:
-            attachments.append({'filename': part.get_filename(),
-                                'content_type': part.get_content_type(),
-                                'data': part.get_payload(decode=True)})
+            attachments.append({
+                'filename': part.get_filename(),
+                'content_type': part.get_content_type(),
+                'data': part.get_payload(decode=True)
+            })
 
     if 'html' in content and marker in content['html']:
         newpost = extract_content(content['html'], marker[:9])
@@ -401,7 +412,7 @@ def process_email(message):
     # Translate marker with locale from email address
     rq_headers = [('Accept-Language', locale)]
     with app.test_request_context('/process_email', headers=rq_headers):
-        marker = unicode(MAIL_REPLY_MARKER)
+        marker = text_type(MAIL_REPLY_MARKER)
 
     # Extract text and attachments from message
     try:
@@ -420,11 +431,8 @@ def process_email(message):
         obj_meta = post.meta.setdefault('abilian.sbe.forum', {})
         obj_meta['origin'] = u'email'
         obj_meta['send_by_email'] = True
-        activity.send(app,
-                      actor=g.user,
-                      verb='post',
-                      object=post,
-                      target=community)
+        activity.send(
+            app, actor=g.user, verb='post', object=post, target=community)
 
         for desc in attachments:
             attachment = PostAttachment(name=desc['filename'])
