@@ -6,25 +6,26 @@ from __future__ import absolute_import, print_function
 
 from datetime import date, datetime
 from itertools import groupby
-from urllib import quote
 
 import sqlalchemy as sa
-from flask import (current_app, flash, g, make_response, render_template,
-                   request)
+from flask import current_app, flash, g, make_response, render_template, \
+    request
 from flask_babel import format_date
 from flask_login import current_user
+from six import text_type
+from six.moves.urllib.parse import quote
 from sqlalchemy.orm import joinedload
 from werkzeug.exceptions import BadRequest, NotFound
 
 from abilian.core.util import utc_dt
 from abilian.i18n import _, _l
-from abilian.sbe.apps.communities.blueprint import Blueprint
-from abilian.sbe.apps.communities.views import default_view_kw
 from abilian.web import url_for, views
 from abilian.web.action import ButtonAction, Endpoint
 from abilian.web.nav import BreadcrumbItem
 from abilian.web.views import default_view
 
+from ..communities.blueprint import Blueprint
+from ..communities.views import default_view_kw
 from .forms import PostEditForm, PostForm, ThreadForm
 from .models import Post, PostAttachment, Thread
 from .tasks import send_post_by_email
@@ -32,10 +33,8 @@ from .tasks import send_post_by_email
 # TODO: move to config
 MAX_THREADS = 30
 
-forum = Blueprint("forum",
-                  __name__,
-                  url_prefix="/forum",
-                  template_folder="templates")
+forum = Blueprint(
+    "forum", __name__, url_prefix="/forum", template_folder="templates")
 route = forum.route
 
 
@@ -53,9 +52,11 @@ def post_kw_view_func(kw, obj, obj_type, obj_id, **kwargs):
 def init_forum_values(endpoint, values):
     g.current_tab = 'forum'
 
-    g.breadcrumb.append(BreadcrumbItem(
-        label=_l(u'Conversations'),
-        url=Endpoint('forum.index', community_id=g.community.slug)))
+    g.breadcrumb.append(
+        BreadcrumbItem(
+            label=_l(u'Conversations'),
+            url=Endpoint(
+                'forum.index', community_id=g.community.slug)))
 
 
 @route('/')
@@ -65,9 +66,8 @@ def index():
         .order_by(Thread.created_at.desc())
     has_more = query.count() > MAX_THREADS
     threads = query.limit(MAX_THREADS).all()
-    return render_template("forum/index.html",
-                           threads=threads,
-                           has_more=has_more)
+    return render_template(
+        "forum/index.html", threads=threads, has_more=has_more)
 
 
 def group_monthly(entities_list):
@@ -93,8 +93,8 @@ def archives():
         .order_by(Thread.created_at.desc()).all()
 
     grouped_threads = group_monthly(all_threads)
-    return render_template('forum/archives.html',
-                           grouped_threads=grouped_threads)
+    return render_template(
+        'forum/archives.html', grouped_threads=grouped_threads)
 
 
 @route('/attachments/')
@@ -114,8 +114,8 @@ def attachments():
     posts_with_attachments.reverse()
 
     grouped_posts = group_monthly(posts_with_attachments)
-    return render_template('forum/attachments.html',
-                           grouped_posts=grouped_posts)
+    return render_template(
+        'forum/attachments.html', grouped_posts=grouped_posts)
 
 
 class BaseThreadView(object):
@@ -163,16 +163,15 @@ default_view(forum, Post, None, kw_func=post_kw_view_func)(thread_view)
 default_view(forum, Thread, 'thread_id', kw_func=default_view_kw)(thread_view)
 
 route('/<int:thread_id>/')(thread_view)
-route('/<int:thread_id>/attachments')(
-    ThreadView.as_view('thread_attachments',
-                       template='forum/thread_attachments.html'))
+route('/<int:thread_id>/attachments')(ThreadView.as_view(
+    'thread_attachments', template='forum/thread_attachments.html'))
 
 
 class ThreadCreate(BaseThreadView, views.ObjectCreate):
-    POST_BUTTON = ButtonAction('form',
-                               'create',
-                               btn_class='primary',
-                               title=_l(u'Post this message'))
+    POST_BUTTON = ButtonAction(
+        'form', 'create', btn_class='primary', title=_l(u'Post this message'))
+
+    title = _("New conversation")
 
     def init_object(self, args, kwargs):
         args, kwargs = super(ThreadCreate, self).init_object(args, kwargs)
@@ -210,8 +209,8 @@ class ThreadCreate(BaseThreadView, views.ObjectCreate):
             name = meta.get('filename', handle)
             mimetype = meta.get('mimetype')
 
-            if not isinstance(name, unicode):
-                name = unicode(name, encoding='utf-8', errors='ignore')
+            if not isinstance(name, text_type):
+                name = text_type(name, encoding='utf-8', errors='ignore')
 
             if not name:
                 continue
@@ -240,8 +239,8 @@ class ThreadCreate(BaseThreadView, views.ObjectCreate):
         return [self.POST_BUTTON, views.object.CANCEL_BUTTON]
 
 
-route('/new_thread/')(ThreadCreate.as_view('new_thread',
-                                           view_endpoint='.thread'))
+route('/new_thread/')(ThreadCreate.as_view(
+    'new_thread', view_endpoint='.thread'))
 
 
 class ThreadPostCreate(ThreadCreate):
@@ -265,8 +264,8 @@ class ThreadPostCreate(ThreadCreate):
         self.obj = self.post
 
 
-route('/<int:thread_id>/')(ThreadPostCreate.as_view('thread_post',
-                                                    view_endpoint='.thread'))
+route('/<int:thread_id>/')(ThreadPostCreate.as_view(
+    'thread_post', view_endpoint='.thread'))
 
 
 class ThreadDelete(BaseThreadView, views.ObjectDelete):
@@ -274,14 +273,15 @@ class ThreadDelete(BaseThreadView, views.ObjectDelete):
     _message_success = _(u'Thread "{title}" deleted.')
 
     def message_success(self):
-        return unicode(self._message_success).format(title=self.obj.title)
+        return text_type(self._message_success).format(title=self.obj.title)
 
 
 route('/<int:thread_id>/delete')(ThreadDelete.as_view('thread_delete'))
 
 
 class ThreadCloseView(BaseThreadView, views.object.BaseObjectView):
-    """Close / Re-open a thread."""
+    """Close / Re-open a thread.
+    """
     methods = ['POST']
     _VALID_ACTIONS = {u'close', u'reopen'}
     CLOSED_MSG = _l(u'The thread is now closed for edition and new '
@@ -304,7 +304,7 @@ class ThreadCloseView(BaseThreadView, views.object.BaseObjectView):
         sa.orm.object_session(self.obj).commit()
 
         msg = self.CLOSED_MSG if is_closed else self.REOPENED_MSG
-        flash(unicode(msg))
+        flash(text_type(msg))
         return self.redirect(url_for(self.obj))
 
 
@@ -352,10 +352,12 @@ class ThreadPostEdit(BaseThreadView, views.ObjectEdit):
         self.obj.body_html = self.message_body
         obj_meta = self.obj.meta.setdefault('abilian.sbe.forum', {})
         history = obj_meta.setdefault('history', [])
-        history.append(dict(user_id=current_user.id,
-                            user=unicode(current_user),
-                            date=utc_dt(datetime.utcnow()).isoformat(),
-                            reason=self.form.reason.data,))
+        history.append(
+            dict(
+                user_id=current_user.id,
+                user=text_type(current_user),
+                date=utc_dt(datetime.utcnow()).isoformat(),
+                reason=self.form.reason.data,))
         self.obj.meta['abilian.sbe.forum'] = obj_meta  # trigger change for SA
 
         attachments_to_remove = []
@@ -382,8 +384,8 @@ class ThreadPostEdit(BaseThreadView, views.ObjectEdit):
             name = meta.get('filename', handle)
             mimetype = meta.get('mimetype')
 
-            if not isinstance(name, unicode):
-                name = unicode(name, encoding='utf-8', errors='ignore')
+            if not isinstance(name, text_type):
+                name = text_type(name, encoding='utf-8', errors='ignore')
 
             if not name:
                 continue
@@ -408,10 +410,8 @@ def attachment_kw_view_func(kw, obj, obj_type, obj_id, **kwargs):
 
 
 @route('/<int:thread_id>/posts/<int:post_id>/attachment/<int:attachment_id>')
-@default_view(forum,
-              PostAttachment,
-              'attachment_id',
-              kw_func=attachment_kw_view_func)
+@default_view(
+    forum, PostAttachment, 'attachment_id', kw_func=attachment_kw_view_func)
 def attachment_download(thread_id, post_id, attachment_id):
     thread = Thread.query.get(thread_id)
     post = Post.query.get(post_id)
@@ -424,7 +424,7 @@ def attachment_download(thread_id, post_id, attachment_id):
     response = make_response(attachment.content)
     response.headers['content-length'] = attachment.content_length
     response.headers['content-type'] = attachment.content_type
-    content_disposition = ('attachment;filename="{}"'.format(quote(
-        attachment.name.encode('utf8'))))
+    content_disposition = ('attachment;filename="{}"'.format(
+        quote(attachment.name.encode('utf8'))))
     response.headers['content-disposition'] = content_disposition
     return response
