@@ -1,9 +1,11 @@
 """Main views.
 """
 
+from __future__ import absolute_import, print_function
+
 from flask import Blueprint, render_template
 
-__all__ = []
+__all__ = ()
 
 blueprint = Blueprint("main", __name__, url_prefix="")
 route = blueprint.route
@@ -16,6 +18,7 @@ route = blueprint.route
 def home():
     return render_template("index.html")
 
+
 # TODO
 # @route("/help/")
 # def help():
