@@ -5,7 +5,7 @@ Default ("home") page for social apps.
 
 def register_plugin(app):
     from .views.social import social
-    from .views import users, groups, sidebars  # noqa
+    from .views import users, groups, sidebars
 
     app.register_blueprint(social)
 
