@@ -1,8 +1,10 @@
 # coding=utf-8
+from __future__ import absolute_import, print_function, unicode_literals
+
 from os.path import dirname, join
 
-from flask import (current_app, flash, g, jsonify, make_response, redirect,
-                   render_template, request, url_for)
+from flask import current_app, flash, g, jsonify, make_response, redirect, \
+    render_template, request, url_for
 from flask_babel import gettext as _
 from sqlalchemy import func
 from werkzeug.exceptions import InternalServerError, NotFound
@@ -17,8 +19,8 @@ from abilian.web.views import default_view
 from .social import social
 from .util import Env
 
-DEFAULT_GROUP_MUGSHOT = open(join(
-    dirname(__file__), "../../../static/images/frog.jpg")).read()
+DEFAULT_GROUP_MUGSHOT = open(
+    join(dirname(__file__), "../../../static/images/frog.jpg"), 'rb').read()
 
 
 @social.route("/groups/")
@@ -28,9 +30,10 @@ def groups():
     if tab == 'all_groups':
         e.groups = Group.query.order_by(Group.name).all()
         if not security.has_role(g.user, "admin"):
-            e.groups = [group
-                        for group in e.groups
-                        if group.public or g.user in group.members]
+            e.groups = [
+                group for group in e.groups
+                if group.public or g.user in group.members
+            ]
     else:
         e.groups = g.user.groups
         e.groups.sort(key=lambda x: x.name)
@@ -76,10 +79,11 @@ def group_post(group_id):
     action = request.form.get('action')
     return_url = request.form.get('return_url')
 
-    membership_actions = frozenset(('add',
-                                    'remove',
-                                    'add-admin',
-                                    'remove-admin',))
+    membership_actions = frozenset((
+        'add',
+        'remove',
+        'add-admin',
+        'remove-admin',))
 
     if action not in ('join', 'leave'):
         assert is_admin(group)
@@ -186,7 +190,7 @@ def groups_json():
         raise InternalServerError()
 
     query = Group.query
-    #query = query.filter(func.lower(Group.name).like(q + "%"))
+    # query = query.filter(func.lower(Group.name).like(q + "%"))
     query = query.order_by(func.lower(Group.name))
     all = query.all()
 
