@@ -5,14 +5,17 @@ TODO: make it smarter (direct access from 'g' using lazy objects?) and
 cacheable.
 """
 
+from __future__ import absolute_import, print_function
+
 from datetime import datetime, timedelta
 
 from flask import g
-from flask.ext.login import current_user
+from flask_login import current_user
 
 from abilian.core.models.subjects import User
 from abilian.sbe.apps.communities.models import Community, Membership
-from abilian.sbe.apps.social.views.social import social
+
+from .social import social
 
 
 class Sidebars(object):
