@@ -2,6 +2,8 @@
 The blueprint for this app.
 """
 
+from __future__ import absolute_import, print_function
+
 from flask import Blueprint, redirect, render_template, url_for
 
 from abilian.core.extensions import db
@@ -16,10 +18,8 @@ __all__ = ['social']
 MAX_LAST_USERS = 15
 MAX_MESSAGES = 15
 
-social = Blueprint("social",
-                   __name__,
-                   url_prefix='/social',
-                   template_folder='../templates')
+social = Blueprint(
+    "social", __name__, url_prefix='/social', template_folder='../templates')
 route = social.route
 
 
@@ -48,9 +48,9 @@ def share():
     message = Message(**d)
     db.session.add(message)
 
-    #tags = message.tags
-    #values = [ {'tag': tag, 'message_id': message.id} for tag in tags ]
-    #db.engine.execute(tagging.insert(), values)
+    # tags = message.tags
+    # values = [ {'tag': tag, 'message_id': message.id} for tag in tags ]
+    # db.engine.execute(tagging.insert(), values)
 
     db.session.commit()
     return redirect(url_for(".home"))
