@@ -1,15 +1,16 @@
 # coding=utf-8
 """
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 import logging
 import pkgutil
 from cgi import escape
 
 import sqlalchemy as sa
-from flask import (Response, current_app, flash, g, jsonify, redirect,
-                   render_template, request)
+from flask import Response, current_app, flash, g, jsonify, redirect, \
+    render_template, request
+from six import text_type
 from sqlalchemy.sql.expression import and_, asc, desc, func, nullslast, or_
 from werkzeug.exceptions import InternalServerError
 
@@ -74,18 +75,18 @@ def users_dt_json():
 
     end = start + length
 
-    q = User.query
-    total_count = q.count()
+    query = User.query
+    total_count = query.count()
 
     if search:
         # TODO: gérer les accents
         filter = or_(
             func.lower(User.first_name).like("%" + search + "%"),
             func.lower(User.last_name).like("%" + search + "%"))
-        q = q.filter(filter) \
+        query = query.filter(filter) \
             .reset_joinpoint()
 
-    count = q.count()
+    count = query.count()
     SORT_COLS = {
         1: [],  # will be set to [User.last_name, User.first_name]
         2: [User.created_at],
@@ -98,13 +99,13 @@ def users_dt_json():
     order_by = map(direction, columns)
 
     # sqlite does not support 'NULLS FIRST|LAST' in ORDER BY clauses
-    engine = q.session.get_bind(User.__mapper__)
+    engine = query.session.get_bind(User.__mapper__)
     if engine.name != 'sqlite':
         order_by[0] = nullslast(order_by[0])
 
-    q = q.order_by(*order_by)
+    query = query.order_by(*order_by)
 
-    users = q.slice(start, end).all()
+    users = query.slice(start, end).all()
 
     data = []
     MUGSHOT_SIZE = 45
@@ -116,9 +117,8 @@ def users_dt_json():
 
         cell0 = (
             u'<a href="{url}"><img src="{src}" width="{size}" height="{size}">'
-            '</a>'.format(url=user_url,
-                          src=mugshot,
-                          size=MUGSHOT_SIZE))
+            '</a>'.format(
+                url=user_url, src=mugshot, size=MUGSHOT_SIZE))
         cell1 = (u'<div class="info"><a href="{user_url}">{name}</a> '
                  u'</div>'.format(**locals()))
         cell2 = age(user.created_at)
@@ -274,13 +274,15 @@ def users_json():
             user, role = user
 
         if role is not None:
-            role = unicode(role)
+            role = text_type(role)
 
-        item = {'id': user.id,
-                'text': u'{} ({})'.format(user.name, user.email),
-                'name': user.name,
-                'email': user.email,
-                'role': role,}
+        item = {
+            'id': user.id,
+            'text': u'{} ({})'.format(user.name, user.email),
+            'name': user.name,
+            'email': user.email,
+            'role': role,
+        }
         results.append(item)
 
     return jsonify({'results': results})
