@@ -2,7 +2,7 @@
 """
 Forms for the Wiki module.
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 from flask import g
 from wtforms import HiddenField, StringField, TextAreaField
@@ -31,19 +31,19 @@ def int_or_none(val):
 
 
 class WikiPageForm(Form):
-    title = StringField(label=_l(u"Title"),
-                        filters=(strip,),
-                        validators=[required()])
+    title = StringField(
+        label=_l(u"Title"), filters=(strip,), validators=[required()])
     body_src = TextAreaField(
         label=_l("Body"),
         filters=(strip, clean_up),
         validators=[required()],
-        widget=TextArea(rows=10, resizeable='vertical'),)
+        widget=TextArea(
+            rows=10, resizeable='vertical'),)
 
     message = StringField(label=_l("Commit message"))
     page_id = HiddenField(filters=(int_or_none,), validators=[flaghidden()])
-    last_revision_id = HiddenField(filters=(int_or_none,),
-                                   validators=[flaghidden()])
+    last_revision_id = HiddenField(
+        filters=(int_or_none,), validators=[flaghidden()])
 
     def validate_title(self, field):
         title = field.data
