@@ -2,7 +2,7 @@
 """
 Set up the markdown converter. Add extensions here (for now).
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 import markdown
 from flask import url_for
@@ -19,9 +19,8 @@ class UrlBuilder(object):
 
     def build(self, label, base, end):
         label = label.strip()
-        return url_for(".page",
-                       community_id=self.page.community.slug,
-                       title=label)
+        return url_for(
+            ".page", community_id=self.page.community.slug, title=label)
 
 
 def convert(page, text):
