@@ -1,21 +1,21 @@
 # coding=utf-8
 """
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 from datetime import datetime
 
-import sqlalchemy as sa
 from flask import g
-from sqlalchemy import (Column, DateTime, ForeignKey, Integer, Unicode,
-                        UnicodeText, UniqueConstraint)
+from sqlalchemy import Column, DateTime, ForeignKey, Integer, Unicode, \
+    UnicodeText, UniqueConstraint
+from sqlalchemy.event import listens_for
 from sqlalchemy.ext.hybrid import hybrid_property
 from sqlalchemy.orm import backref, relationship
 
 from abilian.core.entities import SEARCHABLE, Entity, db
 from abilian.core.models.subjects import User
-from abilian.sbe.apps.communities.models import (Community, CommunityIdColumn,
-                                                 community_content)
+from abilian.sbe.apps.communities.models import Community, CommunityIdColumn, \
+    community_content
 from abilian.sbe.apps.documents.models import BaseContent
 
 from . import markup
@@ -35,13 +35,15 @@ class WikiPage(Entity):
     community = relationship(
         Community,
         primaryjoin=(community_id == Community.id),
-        backref=backref("wiki", cascade="all, delete-orphan"))
+        backref=backref(
+            "wiki", cascade="all, delete-orphan"))
 
     #: The body, using some markup language (Markdown for now)
-    body_src = Column(UnicodeText,
-                      default=u"",
-                      nullable=False,
-                      info=SEARCHABLE | dict(index_to=('text',)))
+    body_src = Column(
+        UnicodeText,
+        default=u"",
+        nullable=False,
+        info=SEARCHABLE | dict(index_to=('text',)))
 
     __table_args__ = (UniqueConstraint('title', 'community_id'),)
 
@@ -90,7 +92,7 @@ class WikiPage(Entity):
         #return bleach.clean(html, strip=True)
 
 
-@sa.event.listens_for(WikiPage.name, "set", active_history=True)
+@listens_for(WikiPage.name, "set", active_history=True)
 def _wiki_sync_name_title(entity, new_value, old_value, initiator):
     """
     Synchronize wikipage name -> title.
@@ -131,15 +133,17 @@ class WikiPageRevision(db.Model):
 
 
 class WikiPageAttachment(BaseContent):
-    __tablename__ = None
+    __tablename__ = None  # type: str
     __indexable__ = False
     __mapper_args__ = {'polymorphic_identity': 'wikipage_attachment'}
     sbe_type = 'wikipage:attachment'
 
     _wikipage_id = Column(Integer, ForeignKey(WikiPage.id), nullable=True)
-    wikipage = relationship(WikiPage,
-                            primaryjoin=(_wikipage_id == WikiPage.id),
-                            backref=backref('attachments',
-                                            lazy='select',
-                                            order_by='WikiPageAttachment.name',
-                                            cascade='all, delete-orphan'))
+    wikipage = relationship(
+        WikiPage,
+        primaryjoin=(_wikipage_id == WikiPage.id),
+        backref=backref(
+            'attachments',
+            lazy='select',
+            order_by='WikiPageAttachment.name',
+            cascade='all, delete-orphan'))
