@@ -1,16 +1,17 @@
 # coding=utf-8
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 import re
-from urllib import quote_plus
 
 from flask import g, url_for
 from markdown import Markdown
 from mock import MagicMock, patch
+from six import text_type
+from six.moves.urllib.parse import quote_plus
 
 from abilian.core.models.subjects import User
-from abilian.sbe.apps.communities.tests.base import (CommunityBaseTestCase,
-                                                     CommunityIndexingTestCase)
+from abilian.sbe.apps.communities.tests.base import CommunityBaseTestCase, \
+    CommunityIndexingTestCase
 from abilian.sbe.apps.wiki.markup import SBEWikiLinkExtension
 
 from . import views
@@ -34,7 +35,7 @@ def test_wikilink_extension():
     with patch('abilian.sbe.apps.wiki.forms.page_exists', page_exists_mock):
         result = md.convert(wikilink)
 
-    qtext = unicode(quote_plus(text.encode('utf-8')))
+    qtext = text_type(quote_plus(text.encode('utf-8')))
     expected = u'<p><a class="wikilink" href="/?title={href}/">{text}</a></p>'
     expected = expected.format(href=qtext, text=text)
     assert expected == result
@@ -44,7 +45,7 @@ def test_wikilink_extension():
     with patch('abilian.sbe.apps.wiki.forms.page_exists', page_exists_mock):
         result = md.convert(wikilink)
 
-    qtext = unicode(quote_plus(text.encode('utf-8')))
+    qtext = text_type(quote_plus(text.encode('utf-8')))
     expected = u'<p><a class="wikilink new" href="/?title={href}/">{text}</a></p>'
     expected = expected.format(href=qtext, text=text)
     assert expected == result
@@ -61,36 +62,36 @@ class TestModels(WikiBaseTestCase):
 
     def test_create_page(self):
         page = WikiPage(title=u"Some page", body_src=u'abc')
-        self.assertEquals(page.title, u'Some page')
-        self.assertEquals(page.name, u'Some page')
-        self.assertEquals(page.body_src, 'abc')
-        self.assertEquals(page.body_html, '<p>abc</p>')
-        self.assertEquals(len(page.revisions), 1)
+        self.assertEqual(page.title, u'Some page')
+        self.assertEqual(page.name, u'Some page')
+        self.assertEqual(page.body_src, 'abc')
+        self.assertEqual(page.body_html, '<p>abc</p>')
+        self.assertEqual(len(page.revisions), 1)
 
         revision = page.revisions[0]
-        self.assertEquals(revision.number, 0)
-        self.assertEquals(revision.author, g.user)
+        self.assertEqual(revision.number, 0)
+        self.assertEqual(revision.author, g.user)
 
     def test_rename_page(self):
         page = WikiPage(title=u"Some page", body_src=u'abc')
-        self.assertEquals(page.title, u'Some page')
-        self.assertEquals(page.name, u'Some page')
+        self.assertEqual(page.title, u'Some page')
+        self.assertEqual(page.name, u'Some page')
         page.title = u'Title Renamed'
-        self.assertEquals(page.title, u'Title Renamed')
-        self.assertEquals(page.name, u'Title Renamed')
+        self.assertEqual(page.title, u'Title Renamed')
+        self.assertEqual(page.name, u'Title Renamed')
 
         page.name = u'Name'
-        self.assertEquals(page.title, u'Name')
-        self.assertEquals(page.name, u'Name')
+        self.assertEqual(page.title, u'Name')
+        self.assertEqual(page.name, u'Name')
 
     def test_create_revision(self):
         page = WikiPage('abc')
         page.create_revision("def", "page updated")
 
-        self.assertEquals(len(page.revisions), 2)
+        self.assertEqual(len(page.revisions), 2)
         last_revision = page.revisions[1]
-        self.assertEquals(last_revision.number, 1)
-        self.assertEquals(last_revision.author, g.user)
+        self.assertEqual(last_revision.number, 1)
+        self.assertEqual(last_revision.author, g.user)
 
 
 class TestIndexing(CommunityIndexingTestCase):
@@ -110,31 +111,32 @@ class TestIndexing(CommunityIndexingTestCase):
         obj_types = (WikiPage.entity_type,)
         with self.login(self.user_no_community):
             res = svc.search(u'community', object_types=obj_types)
-            self.assertEquals(len(res), 0)
+            self.assertEqual(len(res), 0)
 
         with self.login(self.user):
             res = svc.search(u'community', object_types=obj_types)
-            self.assertEquals(len(res), 1)
+            self.assertEqual(len(res), 1)
             hit = res[0]
-            self.assertEquals(hit['object_key'], page.object_key)
+            self.assertEqual(hit['object_key'], page.object_key)
 
         with self.login(self.user_c2):
             res = svc.search(u'community', object_types=obj_types)
-            self.assertEquals(len(res), 1)
+            self.assertEqual(len(res), 1)
             hit = res[0]
-            self.assertEquals(hit['object_key'], page_other.object_key)
+            self.assertEqual(hit['object_key'], page_other.object_key)
 
 
 class TestsViews(WikiBaseTestCase):
 
     def test_home(self):
-        response = self.client.get(url_for("wiki.index",
-                                           community_id=self.community.slug))
+        response = self.client.get(
+            url_for(
+                "wiki.index", community_id=self.community.slug))
         self.assertStatus(response, 302)
 
-        response = self.client.get(url_for("wiki.page",
-                                           title='Home',
-                                           community_id=self.community.slug))
+        response = self.client.get(
+            url_for(
+                "wiki.page", title='Home', community_id=self.community.slug))
         assert response.status_code == 200
 
     def test_create_page_initial_form(self):
@@ -160,17 +162,15 @@ class TestsViews(WikiBaseTestCase):
         response = self.client.post(url, data=data)
         assert response.status_code == 302
 
-        url = url_for("wiki.page",
-                      community_id=self.community.slug,
-                      title=title)
+        url = url_for(
+            "wiki.page", community_id=self.community.slug, title=title)
         response = self.client.get(url)
         assert response.status_code == 200
         self.assertIn(body, response.data)
 
         # edit
-        url = url_for("wiki.page_edit",
-                      community_id=self.community.slug,
-                      title=title)
+        url = url_for(
+            "wiki.page_edit", community_id=self.community.slug, title=title)
         response = self.client.get(url)
         assert response.status_code == 200
 
@@ -180,15 +180,13 @@ class TestsViews(WikiBaseTestCase):
         m = re.search('value="(.*?)"', line)
         page_id = int(m.group(1))
 
-        url = url_for("wiki.page_changes",
-                      community_id=self.community.slug,
-                      title=title)
+        url = url_for(
+            "wiki.page_changes", community_id=self.community.slug, title=title)
         response = self.client.get(url)
         assert response.status_code == 200
 
-        url = url_for("wiki.page_source",
-                      community_id=self.community.slug,
-                      title=title)
+        url = url_for(
+            "wiki.page_source", community_id=self.community.slug, title=title)
         response = self.client.get(url)
         assert response.status_code == 200
 
@@ -198,10 +196,11 @@ class TestsViews(WikiBaseTestCase):
         response = self.client.post(url, data=data)
         assert response.status_code == 302
 
-        url = url_for("wiki.page_compare",
-                      rev0="on",
-                      rev1="on",
-                      community_id=self.community.slug,
-                      title=title)
+        url = url_for(
+            "wiki.page_compare",
+            rev0="on",
+            rev1="on",
+            community_id=self.community.slug,
+            title=title)
         response = self.client.get(url)
         assert response.status_code == 200
