@@ -1,25 +1,27 @@
 # coding=utf-8
 """
 """
-from __future__ import absolute_import
+from __future__ import absolute_import, print_function
 
 import logging
 import uuid
+from pathlib import Path
 
 import pkg_resources
-from pathlib import Path
 
 from abilian.core.util import fqcn
 
 logger = logging.getLogger(__name__)
+
 STATIC_DIR = pkg_resources.resource_filename(__name__, 'static')
 LESSCSS_FILE = str(Path(STATIC_DIR, 'less', 'abilian-sbe.less'))
-JS = ('js/sbe-datatable.js',
-      'js/jquery.fileapi.js',
-      'js/folder.js',
-      'js/folder_edit.js',
-      'js/folder_upload.js',
-      'js/document_viewer.js',)
+JS = (
+    'js/sbe-datatable.js',
+    'js/jquery.fileapi.js',
+    'js/folder.js',
+    'js/folder_edit.js',
+    'js/folder_upload.js',
+    'js/document_viewer.js',)
 
 
 class AbilianSBE(object):
@@ -45,14 +47,15 @@ class AbilianSBE(object):
         app.extensions['babel'].add_translations('abilian.sbe')
 
         # sbe static assets
-        app.add_static_url('abilian/sbe',
-                           STATIC_DIR,
-                           endpoint='abilian_sbe_static')
+        app.add_static_url(
+            'abilian/sbe', STATIC_DIR, endpoint='abilian_sbe_static')
         app.extensions['webassets'].append_path(
             STATIC_DIR, app.static_url_path + '/abilian/sbe')
 
         app.register_asset('js', *JS)
         app.register_asset('css', LESSCSS_FILE)
+
+        # Jinja
         logger.info('Register jinja context processors')
         app.context_processor(inject_template_utils)
 
