@@ -4,9 +4,11 @@
 """
 
 from __future__ import absolute_import
+
 import logging
 
-from flask.ext.script import Manager
+from flask_script import Manager
+
 from abilian.core.commands import setup_abilian_commands
 from abilian.sbe.app import Application
 
@@ -22,4 +24,3 @@ if __name__ == '__main__':
   setup_abilian_commands(manager)
 
   manager.run()
-
